# ./darwinpush/xb/raw/sm.py
# -*- coding: utf-8 -*-
# PyXB bindings for NM:8eb48f8f0e727f488907a816c69d6ed98ba221c7
# Generated 2015-04-23 16:42:14.513978 by PyXB version 1.2.4 using Python 3.4.1.final.0
# Namespace http://www.thalesgroup.com/rtti/PushPort/StationMessages/v1 [xmlns:sm]

from __future__ import unicode_literals
import pyxb
import pyxb.binding
import pyxb.binding.saxer
import io
import pyxb.utils.utility
import pyxb.utils.domutils
import sys
import pyxb.utils.six as _six

# Unique identifier for bindings created at the same time
_GenerationUID = pyxb.utils.utility.UniqueIdentifier('urn:uuid:5049f1de-e9cf-11e4-bb50-a0481ca50ab0')

# Version of PyXB used to generate the bindings
_PyXBVersion = '1.2.4'
# Generated bindings are not compatible across PyXB versions
if pyxb.__version__ != _PyXBVersion:
    raise pyxb.PyXBVersionError(_PyXBVersion)

# Import bindings for namespaces imported into schema
import pyxb.binding.datatypes
import darwinpush.xb.ct as _ImportedBinding_darwinpush_xb_ct

# NOTE: All namespace declarations are reserved within the binding
Namespace = pyxb.namespace.NamespaceForURI('http://www.thalesgroup.com/rtti/PushPort/StationMessages/v1', create_if_missing=True)
Namespace.configureCategories(['typeBinding', 'elementBinding'])

def CreateFromDocument (xml_text, default_namespace=None, location_base=None):
    """Parse the given XML and use the document element to create a
    Python instance.

    @param xml_text An XML document.  This should be data (Python 2
    str or Python 3 bytes), or a text (Python 2 unicode or Python 3
    str) in the L{pyxb._InputEncoding} encoding.

    @keyword default_namespace The L{pyxb.Namespace} instance to use as the
    default namespace where there is no default namespace in scope.
    If unspecified or C{None}, the namespace of the module containing
    this function will be used.

    @keyword location_base: An object to be recorded as the base of all
    L{pyxb.utils.utility.Location} instances associated with events and
    objects handled by the parser.  You might pass the URI from which
    the document was obtained.
    """

    if pyxb.XMLStyle_saxer != pyxb._XMLStyle:
        dom = pyxb.utils.domutils.StringToDOM(xml_text)
        return CreateFromDOM(dom.documentElement, default_namespace=default_namespace)
    if default_namespace is None:
        default_namespace = Namespace.fallbackNamespace()
    saxer = pyxb.binding.saxer.make_parser(fallback_namespace=default_namespace, location_base=location_base)
    handler = saxer.getContentHandler()
    xmld = xml_text
    if isinstance(xmld, _six.text_type):
        xmld = xmld.encode(pyxb._InputEncoding)
    saxer.parse(io.BytesIO(xmld))
    instance = handler.rootObject()
    return instance

def CreateFromDOM (node, default_namespace=None):
    """Create a Python instance from the given DOM node.
    The node tag must correspond to an element declaration in this module.

    @deprecated: Forcing use of DOM interface is unnecessary; use L{CreateFromDocument}."""
    if default_namespace is None:
        default_namespace = Namespace.fallbackNamespace()
    return pyxb.binding.basis.element.AnyCreateFromDOM(node, default_namespace)


# Atomic simple type: {http://www.thalesgroup.com/rtti/PushPort/StationMessages/v1}MsgCategoryType
class MsgCategoryType (pyxb.binding.datatypes.string, pyxb.binding.basis.enumeration_mixin):

    """The category of operator message"""

    _ExpandedName = pyxb.namespace.ExpandedName(Namespace, 'MsgCategoryType')
    _XSDLocation = pyxb.utils.utility.Location('/home/gberg/code/src/fstr/darwinpush/xsd/rttiPPTStationMessages_v1.xsd', 15, 1)
    _Documentation = 'The category of operator message'
MsgCategoryType._CF_enumeration = pyxb.binding.facets.CF_enumeration(value_datatype=MsgCategoryType, enum_prefix=None)
MsgCategoryType.Train = MsgCategoryType._CF_enumeration.addEnumeration(unicode_value='Train', tag='Train')
MsgCategoryType.Station = MsgCategoryType._CF_enumeration.addEnumeration(unicode_value='Station', tag='Station')
MsgCategoryType.Connections = MsgCategoryType._CF_enumeration.addEnumeration(unicode_value='Connections', tag='Connections')
MsgCategoryType.System = MsgCategoryType._CF_enumeration.addEnumeration(unicode_value='System', tag='System')
MsgCategoryType.Misc = MsgCategoryType._CF_enumeration.addEnumeration(unicode_value='Misc', tag='Misc')
MsgCategoryType.PriorTrains = MsgCategoryType._CF_enumeration.addEnumeration(unicode_value='PriorTrains', tag='PriorTrains')
MsgCategoryType.PriorOther = MsgCategoryType._CF_enumeration.addEnumeration(unicode_value='PriorOther', tag='PriorOther')
MsgCategoryType._InitializeFacetMap(MsgCategoryType._CF_enumeration)
Namespace.addCategoryObject('typeBinding', 'MsgCategoryType', MsgCategoryType)

# Atomic simple type: {http://www.thalesgroup.com/rtti/PushPort/StationMessages/v1}MsgSeverityType
class MsgSeverityType (pyxb.binding.datatypes.string, pyxb.binding.basis.enumeration_mixin):

    """The severity of operator message"""

    _ExpandedName = pyxb.namespace.ExpandedName(Namespace, 'MsgSeverityType')
    _XSDLocation = pyxb.utils.utility.Location('/home/gberg/code/src/fstr/darwinpush/xsd/rttiPPTStationMessages_v1.xsd', 29, 1)
    _Documentation = 'The severity of operator message'
MsgSeverityType._CF_enumeration = pyxb.binding.facets.CF_enumeration(value_datatype=MsgSeverityType, enum_prefix=None)
MsgSeverityType.n0 = MsgSeverityType._CF_enumeration.addEnumeration(unicode_value='0', tag='n0')
MsgSeverityType.n1 = MsgSeverityType._CF_enumeration.addEnumeration(unicode_value='1', tag='n1')
MsgSeverityType.n2 = MsgSeverityType._CF_enumeration.addEnumeration(unicode_value='2', tag='n2')
MsgSeverityType.n3 = MsgSeverityType._CF_enumeration.addEnumeration(unicode_value='3', tag='n3')
MsgSeverityType._InitializeFacetMap(MsgSeverityType._CF_enumeration)
Namespace.addCategoryObject('typeBinding', 'MsgSeverityType', MsgSeverityType)

# Complex type [anonymous] with content type MIXED
class CTD_ANON (pyxb.binding.basis.complexTypeDefinition):
    """The content of the message"""
    _TypeDefinition = None
    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_MIXED
    _Abstract = False
    _ExpandedName = None
    _XSDLocation = pyxb.utils.utility.Location('/home/gberg/code/src/fstr/darwinpush/xsd/rttiPPTStationMessages_v1.xsd', 58, 4)
    _ElementMap = {}
    _AttributeMap = {}
    # Base type is pyxb.binding.datatypes.anyType
    
    # Element {http://www.thalesgroup.com/rtti/PushPort/StationMessages/v1}p uses Python identifier p
    __p = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'p'), 'p', '__httpwww_thalesgroup_comrttiPushPortStationMessagesv1_CTD_ANON_httpwww_thalesgroup_comrttiPushPortStationMessagesv1p', True, pyxb.utils.utility.Location('/home/gberg/code/src/fstr/darwinpush/xsd/rttiPPTStationMessages_v1.xsd', 84, 1), )

    
    p = property(__p.value, __p.set, None, 'Defines an HTML paragraph')

    
    # Element {http://www.thalesgroup.com/rtti/PushPort/StationMessages/v1}a uses Python identifier a
    __a = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'a'), 'a', '__httpwww_thalesgroup_comrttiPushPortStationMessagesv1_CTD_ANON_httpwww_thalesgroup_comrttiPushPortStationMessagesv1a', True, pyxb.utils.utility.Location('/home/gberg/code/src/fstr/darwinpush/xsd/rttiPPTStationMessages_v1.xsd', 94, 1), )

    
    a = property(__a.value, __a.set, None, 'Defines an HTML anchor')

    _ElementMap.update({
        __p.name() : __p,
        __a.name() : __a
    })
    _AttributeMap.update({
        
    })



# Complex type [anonymous] with content type MIXED
class CTD_ANON_ (pyxb.binding.basis.complexTypeDefinition):
    """Defines an HTML paragraph"""
    _TypeDefinition = None
    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_MIXED
    _Abstract = False
    _ExpandedName = None
    _XSDLocation = pyxb.utils.utility.Location('/home/gberg/code/src/fstr/darwinpush/xsd/rttiPPTStationMessages_v1.xsd', 88, 2)
    _ElementMap = {}
    _AttributeMap = {}
    # Base type is pyxb.binding.datatypes.anyType
    
    # Element {http://www.thalesgroup.com/rtti/PushPort/StationMessages/v1}a uses Python identifier a
    __a = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'a'), 'a', '__httpwww_thalesgroup_comrttiPushPortStationMessagesv1_CTD_ANON__httpwww_thalesgroup_comrttiPushPortStationMessagesv1a', True, pyxb.utils.utility.Location('/home/gberg/code/src/fstr/darwinpush/xsd/rttiPPTStationMessages_v1.xsd', 94, 1), )

    
    a = property(__a.value, __a.set, None, 'Defines an HTML anchor')

    _ElementMap.update({
        __a.name() : __a
    })
    _AttributeMap.update({
        
    })



# Complex type [anonymous] with content type SIMPLE
class CTD_ANON_2 (pyxb.binding.basis.complexTypeDefinition):
    """Defines an HTML anchor"""
    _TypeDefinition = pyxb.binding.datatypes.string
    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_SIMPLE
    _Abstract = False
    _ExpandedName = None
    _XSDLocation = pyxb.utils.utility.Location('/home/gberg/code/src/fstr/darwinpush/xsd/rttiPPTStationMessages_v1.xsd', 98, 2)
    _ElementMap = {}
    _AttributeMap = {}
    # Base type is pyxb.binding.datatypes.string
    
    # Attribute href uses Python identifier href
    __href = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, 'href'), 'href', '__httpwww_thalesgroup_comrttiPushPortStationMessagesv1_CTD_ANON_2_href', pyxb.binding.datatypes.string, required=True)
    __href._DeclarationLocation = pyxb.utils.utility.Location('/home/gberg/code/src/fstr/darwinpush/xsd/rttiPPTStationMessages_v1.xsd', 101, 5)
    __href._UseLocation = pyxb.utils.utility.Location('/home/gberg/code/src/fstr/darwinpush/xsd/rttiPPTStationMessages_v1.xsd', 101, 5)
    
    href = property(__href.value, __href.set, None, None)

    _ElementMap.update({
        
    })
    _AttributeMap.update({
        __href.name() : __href
    })



# Complex type {http://www.thalesgroup.com/rtti/PushPort/StationMessages/v1}StationMessage with content type ELEMENT_ONLY
class StationMessage (pyxb.binding.basis.complexTypeDefinition):
    """Darwin Workstation Station Message"""
    _TypeDefinition = None
    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_ELEMENT_ONLY
    _Abstract = False
    _ExpandedName = pyxb.namespace.ExpandedName(Namespace, 'StationMessage')
    _XSDLocation = pyxb.utils.utility.Location('/home/gberg/code/src/fstr/darwinpush/xsd/rttiPPTStationMessages_v1.xsd', 41, 1)
    _ElementMap = {}
    _AttributeMap = {}
    # Base type is pyxb.binding.datatypes.anyType
    
    # Element {http://www.thalesgroup.com/rtti/PushPort/StationMessages/v1}Station uses Python identifier Station
    __Station = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'Station'), 'Station', '__httpwww_thalesgroup_comrttiPushPortStationMessagesv1_StationMessage_httpwww_thalesgroup_comrttiPushPortStationMessagesv1Station', True, pyxb.utils.utility.Location('/home/gberg/code/src/fstr/darwinpush/xsd/rttiPPTStationMessages_v1.xsd', 46, 3), )

    
    Station = property(__Station.value, __Station.set, None, 'The Stations the message is being applied to')

    
    # Element {http://www.thalesgroup.com/rtti/PushPort/StationMessages/v1}Msg uses Python identifier Msg
    __Msg = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'Msg'), 'Msg', '__httpwww_thalesgroup_comrttiPushPortStationMessagesv1_StationMessage_httpwww_thalesgroup_comrttiPushPortStationMessagesv1Msg', False, pyxb.utils.utility.Location('/home/gberg/code/src/fstr/darwinpush/xsd/rttiPPTStationMessages_v1.xsd', 54, 3), )

    
    Msg = property(__Msg.value, __Msg.set, None, 'The content of the message')

    
    # Attribute id uses Python identifier id
    __id = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, 'id'), 'id', '__httpwww_thalesgroup_comrttiPushPortStationMessagesv1_StationMessage_id', pyxb.binding.datatypes.int, required=True)
    __id._DeclarationLocation = pyxb.utils.utility.Location('/home/gberg/code/src/fstr/darwinpush/xsd/rttiPPTStationMessages_v1.xsd', 66, 2)
    __id._UseLocation = pyxb.utils.utility.Location('/home/gberg/code/src/fstr/darwinpush/xsd/rttiPPTStationMessages_v1.xsd', 66, 2)
    
    id = property(__id.value, __id.set, None, None)

    
    # Attribute cat uses Python identifier cat
    __cat = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, 'cat'), 'cat', '__httpwww_thalesgroup_comrttiPushPortStationMessagesv1_StationMessage_cat', MsgCategoryType, required=True)
    __cat._DeclarationLocation = pyxb.utils.utility.Location('/home/gberg/code/src/fstr/darwinpush/xsd/rttiPPTStationMessages_v1.xsd', 67, 2)
    __cat._UseLocation = pyxb.utils.utility.Location('/home/gberg/code/src/fstr/darwinpush/xsd/rttiPPTStationMessages_v1.xsd', 67, 2)
    
    cat = property(__cat.value, __cat.set, None, 'The category of message')

    
    # Attribute sev uses Python identifier sev
    __sev = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, 'sev'), 'sev', '__httpwww_thalesgroup_comrttiPushPortStationMessagesv1_StationMessage_sev', MsgSeverityType, required=True)
    __sev._DeclarationLocation = pyxb.utils.utility.Location('/home/gberg/code/src/fstr/darwinpush/xsd/rttiPPTStationMessages_v1.xsd', 72, 2)
    __sev._UseLocation = pyxb.utils.utility.Location('/home/gberg/code/src/fstr/darwinpush/xsd/rttiPPTStationMessages_v1.xsd', 72, 2)
    
    sev = property(__sev.value, __sev.set, None, 'The severity of the message')

    
    # Attribute suppress uses Python identifier suppress
    __suppress = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, 'suppress'), 'suppress', '__httpwww_thalesgroup_comrttiPushPortStationMessagesv1_StationMessage_suppress', pyxb.binding.datatypes.boolean, unicode_default='false')
    __suppress._DeclarationLocation = pyxb.utils.utility.Location('/home/gberg/code/src/fstr/darwinpush/xsd/rttiPPTStationMessages_v1.xsd', 77, 2)
    __suppress._UseLocation = pyxb.utils.utility.Location('/home/gberg/code/src/fstr/darwinpush/xsd/rttiPPTStationMessages_v1.xsd', 77, 2)
    
    suppress = property(__suppress.value, __suppress.set, None, 'Whether the train running information is suppressed to the public')

    _ElementMap.update({
        __Station.name() : __Station,
        __Msg.name() : __Msg
    })
    _AttributeMap.update({
        __id.name() : __id,
        __cat.name() : __cat,
        __sev.name() : __sev,
        __suppress.name() : __suppress
    })
Namespace.addCategoryObject('typeBinding', 'StationMessage', StationMessage)


# Complex type [anonymous] with content type EMPTY
class CTD_ANON_3 (pyxb.binding.basis.complexTypeDefinition):
    """The Stations the message is being applied to"""
    _TypeDefinition = None
    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_EMPTY
    _Abstract = False
    _ExpandedName = None
    _XSDLocation = pyxb.utils.utility.Location('/home/gberg/code/src/fstr/darwinpush/xsd/rttiPPTStationMessages_v1.xsd', 50, 4)
    _ElementMap = {}
    _AttributeMap = {}
    # Base type is pyxb.binding.datatypes.anyType
    
    # Attribute crs uses Python identifier crs
    __crs = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, 'crs'), 'crs', '__httpwww_thalesgroup_comrttiPushPortStationMessagesv1_CTD_ANON_3_crs', _ImportedBinding_darwinpush_xb_ct.CrsType, required=True)
    __crs._DeclarationLocation = pyxb.utils.utility.Location('/home/gberg/code/src/fstr/darwinpush/xsd/rttiPPTStationMessages_v1.xsd', 51, 5)
    __crs._UseLocation = pyxb.utils.utility.Location('/home/gberg/code/src/fstr/darwinpush/xsd/rttiPPTStationMessages_v1.xsd', 51, 5)
    
    crs = property(__crs.value, __crs.set, None, None)

    _ElementMap.update({
        
    })
    _AttributeMap.update({
        __crs.name() : __crs
    })



p = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'p'), CTD_ANON_, documentation='Defines an HTML paragraph', location=pyxb.utils.utility.Location('/home/gberg/code/src/fstr/darwinpush/xsd/rttiPPTStationMessages_v1.xsd', 84, 1))
Namespace.addCategoryObject('elementBinding', p.name().localName(), p)

a = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'a'), CTD_ANON_2, documentation='Defines an HTML anchor', location=pyxb.utils.utility.Location('/home/gberg/code/src/fstr/darwinpush/xsd/rttiPPTStationMessages_v1.xsd', 94, 1))
Namespace.addCategoryObject('elementBinding', a.name().localName(), a)



CTD_ANON._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'p'), CTD_ANON_, scope=CTD_ANON, documentation='Defines an HTML paragraph', location=pyxb.utils.utility.Location('/home/gberg/code/src/fstr/darwinpush/xsd/rttiPPTStationMessages_v1.xsd', 84, 1)))

CTD_ANON._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'a'), CTD_ANON_2, scope=CTD_ANON, documentation='Defines an HTML anchor', location=pyxb.utils.utility.Location('/home/gberg/code/src/fstr/darwinpush/xsd/rttiPPTStationMessages_v1.xsd', 94, 1)))

def _BuildAutomaton ():
    # Remove this helper function from the namespace after it is invoked
    global _BuildAutomaton
    del _BuildAutomaton
    import pyxb.utils.fac as fac

    counters = set()
    cc_0 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('/home/gberg/code/src/fstr/darwinpush/xsd/rttiPPTStationMessages_v1.xsd', 60, 6))
    counters.add(cc_0)
    cc_1 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('/home/gberg/code/src/fstr/darwinpush/xsd/rttiPPTStationMessages_v1.xsd', 61, 6))
    counters.add(cc_1)
    states = []
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_0, False))
    symbol = pyxb.binding.content.ElementUse(CTD_ANON._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'p')), pyxb.utils.utility.Location('/home/gberg/code/src/fstr/darwinpush/xsd/rttiPPTStationMessages_v1.xsd', 60, 6))
    st_0 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_0)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_1, False))
    symbol = pyxb.binding.content.ElementUse(CTD_ANON._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'a')), pyxb.utils.utility.Location('/home/gberg/code/src/fstr/darwinpush/xsd/rttiPPTStationMessages_v1.xsd', 61, 6))
    st_1 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_1)
    transitions = []
    transitions.append(fac.Transition(st_0, [
        fac.UpdateInstruction(cc_0, True) ]))
    st_0._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_1, [
        fac.UpdateInstruction(cc_1, True) ]))
    st_1._set_transitionSet(transitions)
    return fac.Automaton(states, counters, True, containing_state=None)
CTD_ANON._Automaton = _BuildAutomaton()




CTD_ANON_._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'a'), CTD_ANON_2, scope=CTD_ANON_, documentation='Defines an HTML anchor', location=pyxb.utils.utility.Location('/home/gberg/code/src/fstr/darwinpush/xsd/rttiPPTStationMessages_v1.xsd', 94, 1)))

def _BuildAutomaton_ ():
    # Remove this helper function from the namespace after it is invoked
    global _BuildAutomaton_
    del _BuildAutomaton_
    import pyxb.utils.fac as fac

    counters = set()
    cc_0 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('/home/gberg/code/src/fstr/darwinpush/xsd/rttiPPTStationMessages_v1.xsd', 90, 4))
    counters.add(cc_0)
    states = []
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_0, False))
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'a')), pyxb.utils.utility.Location('/home/gberg/code/src/fstr/darwinpush/xsd/rttiPPTStationMessages_v1.xsd', 90, 4))
    st_0 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_0)
    transitions = []
    transitions.append(fac.Transition(st_0, [
        fac.UpdateInstruction(cc_0, True) ]))
    st_0._set_transitionSet(transitions)
    return fac.Automaton(states, counters, True, containing_state=None)
CTD_ANON_._Automaton = _BuildAutomaton_()




StationMessage._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'Station'), CTD_ANON_3, scope=StationMessage, documentation='The Stations the message is being applied to', location=pyxb.utils.utility.Location('/home/gberg/code/src/fstr/darwinpush/xsd/rttiPPTStationMessages_v1.xsd', 46, 3)))

StationMessage._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'Msg'), CTD_ANON, scope=StationMessage, documentation='The content of the message', location=pyxb.utils.utility.Location('/home/gberg/code/src/fstr/darwinpush/xsd/rttiPPTStationMessages_v1.xsd', 54, 3)))

def _BuildAutomaton_2 ():
    # Remove this helper function from the namespace after it is invoked
    global _BuildAutomaton_2
    del _BuildAutomaton_2
    import pyxb.utils.fac as fac

    counters = set()
    cc_0 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('/home/gberg/code/src/fstr/darwinpush/xsd/rttiPPTStationMessages_v1.xsd', 46, 3))
    counters.add(cc_0)
    states = []
    final_update = None
    symbol = pyxb.binding.content.ElementUse(StationMessage._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'Station')), pyxb.utils.utility.Location('/home/gberg/code/src/fstr/darwinpush/xsd/rttiPPTStationMessages_v1.xsd', 46, 3))
    st_0 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_0)
    final_update = set()
    symbol = pyxb.binding.content.ElementUse(StationMessage._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'Msg')), pyxb.utils.utility.Location('/home/gberg/code/src/fstr/darwinpush/xsd/rttiPPTStationMessages_v1.xsd', 54, 3))
    st_1 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_1)
    transitions = []
    transitions.append(fac.Transition(st_0, [
        fac.UpdateInstruction(cc_0, True) ]))
    transitions.append(fac.Transition(st_1, [
        fac.UpdateInstruction(cc_0, False) ]))
    st_0._set_transitionSet(transitions)
    transitions = []
    st_1._set_transitionSet(transitions)
    return fac.Automaton(states, counters, False, containing_state=None)
StationMessage._Automaton = _BuildAutomaton_2()




# ./darwinpush/xb/raw/ta.py
# -*- coding: utf-8 -*-
# PyXB bindings for NM:697e0ad31a5bd138fa72077ce2e9fb240afaf510
# Generated 2015-04-23 16:42:14.514455 by PyXB version 1.2.4 using Python 3.4.1.final.0
# Namespace http://www.thalesgroup.com/rtti/PushPort/TrainAlerts/v1 [xmlns:ta]

from __future__ import unicode_literals
import pyxb
import pyxb.binding
import pyxb.binding.saxer
import io
import pyxb.utils.utility
import pyxb.utils.domutils
import sys
import pyxb.utils.six as _six

# Unique identifier for bindings created at the same time
_GenerationUID = pyxb.utils.utility.UniqueIdentifier('urn:uuid:5049f1de-e9cf-11e4-bb50-a0481ca50ab0')

# Version of PyXB used to generate the bindings
_PyXBVersion = '1.2.4'
# Generated bindings are not compatible across PyXB versions
if pyxb.__version__ != _PyXBVersion:
    raise pyxb.PyXBVersionError(_PyXBVersion)

# Import bindings for namespaces imported into schema
import pyxb.binding.datatypes
import darwinpush.xb.ct as _ImportedBinding_darwinpush_xb_ct

# NOTE: All namespace declarations are reserved within the binding
Namespace = pyxb.namespace.NamespaceForURI('http://www.thalesgroup.com/rtti/PushPort/TrainAlerts/v1', create_if_missing=True)
Namespace.configureCategories(['typeBinding', 'elementBinding'])

def CreateFromDocument (xml_text, default_namespace=None, location_base=None):
    """Parse the given XML and use the document element to create a
    Python instance.

    @param xml_text An XML document.  This should be data (Python 2
    str or Python 3 bytes), or a text (Python 2 unicode or Python 3
    str) in the L{pyxb._InputEncoding} encoding.

    @keyword default_namespace The L{pyxb.Namespace} instance to use as the
    default namespace where there is no default namespace in scope.
    If unspecified or C{None}, the namespace of the module containing
    this function will be used.

    @keyword location_base: An object to be recorded as the base of all
    L{pyxb.utils.utility.Location} instances associated with events and
    objects handled by the parser.  You might pass the URI from which
    the document was obtained.
    """

    if pyxb.XMLStyle_saxer != pyxb._XMLStyle:
        dom = pyxb.utils.domutils.StringToDOM(xml_text)
        return CreateFromDOM(dom.documentElement, default_namespace=default_namespace)
    if default_namespace is None:
        default_namespace = Namespace.fallbackNamespace()
    saxer = pyxb.binding.saxer.make_parser(fallback_namespace=default_namespace, location_base=location_base)
    handler = saxer.getContentHandler()
    xmld = xml_text
    if isinstance(xmld, _six.text_type):
        xmld = xmld.encode(pyxb._InputEncoding)
    saxer.parse(io.BytesIO(xmld))
    instance = handler.rootObject()
    return instance

def CreateFromDOM (node, default_namespace=None):
    """Create a Python instance from the given DOM node.
    The node tag must correspond to an element declaration in this module.

    @deprecated: Forcing use of DOM interface is unnecessary; use L{CreateFromDocument}."""
    if default_namespace is None:
        default_namespace = Namespace.fallbackNamespace()
    return pyxb.binding.basis.element.AnyCreateFromDOM(node, default_namespace)


# Atomic simple type: {http://www.thalesgroup.com/rtti/PushPort/TrainAlerts/v1}AlertAudienceType
class AlertAudienceType (pyxb.binding.datatypes.string, pyxb.binding.basis.enumeration_mixin):

    """Alert Audience Data Type"""

    _ExpandedName = pyxb.namespace.ExpandedName(Namespace, 'AlertAudienceType')
    _XSDLocation = pyxb.utils.utility.Location('/home/gberg/code/src/fstr/darwinpush/xsd/rttiPPTTrainAlerts_v1.xsd', 15, 1)
    _Documentation = 'Alert Audience Data Type'
AlertAudienceType._CF_enumeration = pyxb.binding.facets.CF_enumeration(value_datatype=AlertAudienceType, enum_prefix=None)
AlertAudienceType.Customer = AlertAudienceType._CF_enumeration.addEnumeration(unicode_value='Customer', tag='Customer')
AlertAudienceType.Staff = AlertAudienceType._CF_enumeration.addEnumeration(unicode_value='Staff', tag='Staff')
AlertAudienceType.Operations = AlertAudienceType._CF_enumeration.addEnumeration(unicode_value='Operations', tag='Operations')
AlertAudienceType._InitializeFacetMap(AlertAudienceType._CF_enumeration)
Namespace.addCategoryObject('typeBinding', 'AlertAudienceType', AlertAudienceType)

# Atomic simple type: {http://www.thalesgroup.com/rtti/PushPort/TrainAlerts/v1}AlertType
class AlertType (pyxb.binding.datatypes.string, pyxb.binding.basis.enumeration_mixin):

    """Alert Type Data Type"""

    _ExpandedName = pyxb.namespace.ExpandedName(Namespace, 'AlertType')
    _XSDLocation = pyxb.utils.utility.Location('/home/gberg/code/src/fstr/darwinpush/xsd/rttiPPTTrainAlerts_v1.xsd', 25, 1)
    _Documentation = 'Alert Type Data Type'
AlertType._CF_enumeration = pyxb.binding.facets.CF_enumeration(value_datatype=AlertType, enum_prefix=None)
AlertType.Normal = AlertType._CF_enumeration.addEnumeration(unicode_value='Normal', tag='Normal')
AlertType.Forced = AlertType._CF_enumeration.addEnumeration(unicode_value='Forced', tag='Forced')
AlertType._InitializeFacetMap(AlertType._CF_enumeration)
Namespace.addCategoryObject('typeBinding', 'AlertType', AlertType)

# Complex type {http://www.thalesgroup.com/rtti/PushPort/TrainAlerts/v1}TrainAlert with content type ELEMENT_ONLY
class TrainAlert (pyxb.binding.basis.complexTypeDefinition):
    """Train Alert"""
    _TypeDefinition = None
    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_ELEMENT_ONLY
    _Abstract = False
    _ExpandedName = pyxb.namespace.ExpandedName(Namespace, 'TrainAlert')
    _XSDLocation = pyxb.utils.utility.Location('/home/gberg/code/src/fstr/darwinpush/xsd/rttiPPTTrainAlerts_v1.xsd', 35, 1)
    _ElementMap = {}
    _AttributeMap = {}
    # Base type is pyxb.binding.datatypes.anyType
    
    # Element {http://www.thalesgroup.com/rtti/PushPort/TrainAlerts/v1}AlertID uses Python identifier AlertID
    __AlertID = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'AlertID'), 'AlertID', '__httpwww_thalesgroup_comrttiPushPortTrainAlertsv1_TrainAlert_httpwww_thalesgroup_comrttiPushPortTrainAlertsv1AlertID', False, pyxb.utils.utility.Location('/home/gberg/code/src/fstr/darwinpush/xsd/rttiPPTTrainAlerts_v1.xsd', 40, 3), )

    
    AlertID = property(__AlertID.value, __AlertID.set, None, 'TODO')

    
    # Element {http://www.thalesgroup.com/rtti/PushPort/TrainAlerts/v1}AlertServices uses Python identifier AlertServices
    __AlertServices = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'AlertServices'), 'AlertServices', '__httpwww_thalesgroup_comrttiPushPortTrainAlertsv1_TrainAlert_httpwww_thalesgroup_comrttiPushPortTrainAlertsv1AlertServices', False, pyxb.utils.utility.Location('/home/gberg/code/src/fstr/darwinpush/xsd/rttiPPTTrainAlerts_v1.xsd', 45, 3), )

    
    AlertServices = property(__AlertServices.value, __AlertServices.set, None, 'TODO')

    
    # Element {http://www.thalesgroup.com/rtti/PushPort/TrainAlerts/v1}SendAlertBySMS uses Python identifier SendAlertBySMS
    __SendAlertBySMS = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'SendAlertBySMS'), 'SendAlertBySMS', '__httpwww_thalesgroup_comrttiPushPortTrainAlertsv1_TrainAlert_httpwww_thalesgroup_comrttiPushPortTrainAlertsv1SendAlertBySMS', False, pyxb.utils.utility.Location('/home/gberg/code/src/fstr/darwinpush/xsd/rttiPPTTrainAlerts_v1.xsd', 50, 3), )

    
    SendAlertBySMS = property(__SendAlertBySMS.value, __SendAlertBySMS.set, None, 'TODO')

    
    # Element {http://www.thalesgroup.com/rtti/PushPort/TrainAlerts/v1}SendAlertByEmail uses Python identifier SendAlertByEmail
    __SendAlertByEmail = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'SendAlertByEmail'), 'SendAlertByEmail', '__httpwww_thalesgroup_comrttiPushPortTrainAlertsv1_TrainAlert_httpwww_thalesgroup_comrttiPushPortTrainAlertsv1SendAlertByEmail', False, pyxb.utils.utility.Location('/home/gberg/code/src/fstr/darwinpush/xsd/rttiPPTTrainAlerts_v1.xsd', 55, 3), )

    
    SendAlertByEmail = property(__SendAlertByEmail.value, __SendAlertByEmail.set, None, 'TODO')

    
    # Element {http://www.thalesgroup.com/rtti/PushPort/TrainAlerts/v1}SendAlertByTwitter uses Python identifier SendAlertByTwitter
    __SendAlertByTwitter = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'SendAlertByTwitter'), 'SendAlertByTwitter', '__httpwww_thalesgroup_comrttiPushPortTrainAlertsv1_TrainAlert_httpwww_thalesgroup_comrttiPushPortTrainAlertsv1SendAlertByTwitter', False, pyxb.utils.utility.Location('/home/gberg/code/src/fstr/darwinpush/xsd/rttiPPTTrainAlerts_v1.xsd', 60, 3), )

    
    SendAlertByTwitter = property(__SendAlertByTwitter.value, __SendAlertByTwitter.set, None, 'TODO')

    
    # Element {http://www.thalesgroup.com/rtti/PushPort/TrainAlerts/v1}Source uses Python identifier Source
    __Source = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'Source'), 'Source', '__httpwww_thalesgroup_comrttiPushPortTrainAlertsv1_TrainAlert_httpwww_thalesgroup_comrttiPushPortTrainAlertsv1Source', False, pyxb.utils.utility.Location('/home/gberg/code/src/fstr/darwinpush/xsd/rttiPPTTrainAlerts_v1.xsd', 65, 3), )

    
    Source = property(__Source.value, __Source.set, None, 'TODO')

    
    # Element {http://www.thalesgroup.com/rtti/PushPort/TrainAlerts/v1}AlertText uses Python identifier AlertText
    __AlertText = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'AlertText'), 'AlertText', '__httpwww_thalesgroup_comrttiPushPortTrainAlertsv1_TrainAlert_httpwww_thalesgroup_comrttiPushPortTrainAlertsv1AlertText', False, pyxb.utils.utility.Location('/home/gberg/code/src/fstr/darwinpush/xsd/rttiPPTTrainAlerts_v1.xsd', 70, 3), )

    
    AlertText = property(__AlertText.value, __AlertText.set, None, 'TODO')

    
    # Element {http://www.thalesgroup.com/rtti/PushPort/TrainAlerts/v1}Audience uses Python identifier Audience
    __Audience = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'Audience'), 'Audience', '__httpwww_thalesgroup_comrttiPushPortTrainAlertsv1_TrainAlert_httpwww_thalesgroup_comrttiPushPortTrainAlertsv1Audience', False, pyxb.utils.utility.Location('/home/gberg/code/src/fstr/darwinpush/xsd/rttiPPTTrainAlerts_v1.xsd', 75, 3), )

    
    Audience = property(__Audience.value, __Audience.set, None, 'TODO')

    
    # Element {http://www.thalesgroup.com/rtti/PushPort/TrainAlerts/v1}AlertType uses Python identifier AlertType
    __AlertType = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'AlertType'), 'AlertType', '__httpwww_thalesgroup_comrttiPushPortTrainAlertsv1_TrainAlert_httpwww_thalesgroup_comrttiPushPortTrainAlertsv1AlertType', False, pyxb.utils.utility.Location('/home/gberg/code/src/fstr/darwinpush/xsd/rttiPPTTrainAlerts_v1.xsd', 80, 3), )

    
    AlertType = property(__AlertType.value, __AlertType.set, None, 'TODO')

    
    # Element {http://www.thalesgroup.com/rtti/PushPort/TrainAlerts/v1}CopiedFromAlertID uses Python identifier CopiedFromAlertID
    __CopiedFromAlertID = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'CopiedFromAlertID'), 'CopiedFromAlertID', '__httpwww_thalesgroup_comrttiPushPortTrainAlertsv1_TrainAlert_httpwww_thalesgroup_comrttiPushPortTrainAlertsv1CopiedFromAlertID', False, pyxb.utils.utility.Location('/home/gberg/code/src/fstr/darwinpush/xsd/rttiPPTTrainAlerts_v1.xsd', 85, 3), )

    
    CopiedFromAlertID = property(__CopiedFromAlertID.value, __CopiedFromAlertID.set, None, 'TODO')

    
    # Element {http://www.thalesgroup.com/rtti/PushPort/TrainAlerts/v1}CopiedFromSource uses Python identifier CopiedFromSource
    __CopiedFromSource = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'CopiedFromSource'), 'CopiedFromSource', '__httpwww_thalesgroup_comrttiPushPortTrainAlertsv1_TrainAlert_httpwww_thalesgroup_comrttiPushPortTrainAlertsv1CopiedFromSource', False, pyxb.utils.utility.Location('/home/gberg/code/src/fstr/darwinpush/xsd/rttiPPTTrainAlerts_v1.xsd', 90, 3), )

    
    CopiedFromSource = property(__CopiedFromSource.value, __CopiedFromSource.set, None, 'TODO')

    _ElementMap.update({
        __AlertID.name() : __AlertID,
        __AlertServices.name() : __AlertServices,
        __SendAlertBySMS.name() : __SendAlertBySMS,
        __SendAlertByEmail.name() : __SendAlertByEmail,
        __SendAlertByTwitter.name() : __SendAlertByTwitter,
        __Source.name() : __Source,
        __AlertText.name() : __AlertText,
        __Audience.name() : __Audience,
        __AlertType.name() : __AlertType,
        __CopiedFromAlertID.name() : __CopiedFromAlertID,
        __CopiedFromSource.name() : __CopiedFromSource
    })
    _AttributeMap.update({
        
    })
Namespace.addCategoryObject('typeBinding', 'TrainAlert', TrainAlert)


# Complex type {http://www.thalesgroup.com/rtti/PushPort/TrainAlerts/v1}AlertServices with content type ELEMENT_ONLY
class AlertServices (pyxb.binding.basis.complexTypeDefinition):
    """A list of services to which the alert applies"""
    _TypeDefinition = None
    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_ELEMENT_ONLY
    _Abstract = False
    _ExpandedName = pyxb.namespace.ExpandedName(Namespace, 'AlertServices')
    _XSDLocation = pyxb.utils.utility.Location('/home/gberg/code/src/fstr/darwinpush/xsd/rttiPPTTrainAlerts_v1.xsd', 124, 1)
    _ElementMap = {}
    _AttributeMap = {}
    # Base type is pyxb.binding.datatypes.anyType
    
    # Element {http://www.thalesgroup.com/rtti/PushPort/TrainAlerts/v1}AlertService uses Python identifier AlertService
    __AlertService = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'AlertService'), 'AlertService', '__httpwww_thalesgroup_comrttiPushPortTrainAlertsv1_AlertServices_httpwww_thalesgroup_comrttiPushPortTrainAlertsv1AlertService', True, pyxb.utils.utility.Location('/home/gberg/code/src/fstr/darwinpush/xsd/rttiPPTTrainAlerts_v1.xsd', 129, 3), )

    
    AlertService = property(__AlertService.value, __AlertService.set, None, 'TODO')

    _ElementMap.update({
        __AlertService.name() : __AlertService
    })
    _AttributeMap.update({
        
    })
Namespace.addCategoryObject('typeBinding', 'AlertServices', AlertServices)


# Complex type {http://www.thalesgroup.com/rtti/PushPort/TrainAlerts/v1}AlertService with content type ELEMENT_ONLY
class AlertService (pyxb.binding.basis.complexTypeDefinition):
    """TODO"""
    _TypeDefinition = None
    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_ELEMENT_ONLY
    _Abstract = False
    _ExpandedName = pyxb.namespace.ExpandedName(Namespace, 'AlertService')
    _XSDLocation = pyxb.utils.utility.Location('/home/gberg/code/src/fstr/darwinpush/xsd/rttiPPTTrainAlerts_v1.xsd', 97, 1)
    _ElementMap = {}
    _AttributeMap = {}
    # Base type is pyxb.binding.datatypes.anyType
    
    # Element {http://www.thalesgroup.com/rtti/PushPort/TrainAlerts/v1}Location uses Python identifier Location
    __Location = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'Location'), 'Location', '__httpwww_thalesgroup_comrttiPushPortTrainAlertsv1_AlertService_httpwww_thalesgroup_comrttiPushPortTrainAlertsv1Location', True, pyxb.utils.utility.Location('/home/gberg/code/src/fstr/darwinpush/xsd/rttiPPTTrainAlerts_v1.xsd', 102, 3), )

    
    Location = property(__Location.value, __Location.set, None, 'TODO')

    
    # Attribute RID uses Python identifier RID
    __RID = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, 'RID'), 'RID', '__httpwww_thalesgroup_comrttiPushPortTrainAlertsv1_AlertService_RID', _ImportedBinding_darwinpush_xb_ct.RIDType)
    __RID._DeclarationLocation = pyxb.utils.utility.Location('/home/gberg/code/src/fstr/darwinpush/xsd/rttiPPTTrainAlerts_v1.xsd', 108, 2)
    __RID._UseLocation = pyxb.utils.utility.Location('/home/gberg/code/src/fstr/darwinpush/xsd/rttiPPTTrainAlerts_v1.xsd', 108, 2)
    
    RID = property(__RID.value, __RID.set, None, 'TODO')

    
    # Attribute UID uses Python identifier UID
    __UID = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, 'UID'), 'UID', '__httpwww_thalesgroup_comrttiPushPortTrainAlertsv1_AlertService_UID', _ImportedBinding_darwinpush_xb_ct.UIDType)
    __UID._DeclarationLocation = pyxb.utils.utility.Location('/home/gberg/code/src/fstr/darwinpush/xsd/rttiPPTTrainAlerts_v1.xsd', 113, 2)
    __UID._UseLocation = pyxb.utils.utility.Location('/home/gberg/code/src/fstr/darwinpush/xsd/rttiPPTTrainAlerts_v1.xsd', 113, 2)
    
    UID = property(__UID.value, __UID.set, None, 'TODO')

    
    # Attribute SSD uses Python identifier SSD
    __SSD = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, 'SSD'), 'SSD', '__httpwww_thalesgroup_comrttiPushPortTrainAlertsv1_AlertService_SSD', pyxb.binding.datatypes.date)
    __SSD._DeclarationLocation = pyxb.utils.utility.Location('/home/gberg/code/src/fstr/darwinpush/xsd/rttiPPTTrainAlerts_v1.xsd', 118, 2)
    __SSD._UseLocation = pyxb.utils.utility.Location('/home/gberg/code/src/fstr/darwinpush/xsd/rttiPPTTrainAlerts_v1.xsd', 118, 2)
    
    SSD = property(__SSD.value, __SSD.set, None, 'TODO')

    _ElementMap.update({
        __Location.name() : __Location
    })
    _AttributeMap.update({
        __RID.name() : __RID,
        __UID.name() : __UID,
        __SSD.name() : __SSD
    })
Namespace.addCategoryObject('typeBinding', 'AlertService', AlertService)




TrainAlert._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'AlertID'), pyxb.binding.datatypes.string, scope=TrainAlert, documentation='TODO', location=pyxb.utils.utility.Location('/home/gberg/code/src/fstr/darwinpush/xsd/rttiPPTTrainAlerts_v1.xsd', 40, 3)))

TrainAlert._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'AlertServices'), AlertServices, scope=TrainAlert, documentation='TODO', location=pyxb.utils.utility.Location('/home/gberg/code/src/fstr/darwinpush/xsd/rttiPPTTrainAlerts_v1.xsd', 45, 3)))

TrainAlert._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'SendAlertBySMS'), pyxb.binding.datatypes.boolean, scope=TrainAlert, documentation='TODO', location=pyxb.utils.utility.Location('/home/gberg/code/src/fstr/darwinpush/xsd/rttiPPTTrainAlerts_v1.xsd', 50, 3)))

TrainAlert._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'SendAlertByEmail'), pyxb.binding.datatypes.boolean, scope=TrainAlert, documentation='TODO', location=pyxb.utils.utility.Location('/home/gberg/code/src/fstr/darwinpush/xsd/rttiPPTTrainAlerts_v1.xsd', 55, 3)))

TrainAlert._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'SendAlertByTwitter'), pyxb.binding.datatypes.boolean, scope=TrainAlert, documentation='TODO', location=pyxb.utils.utility.Location('/home/gberg/code/src/fstr/darwinpush/xsd/rttiPPTTrainAlerts_v1.xsd', 60, 3)))

TrainAlert._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'Source'), pyxb.binding.datatypes.string, scope=TrainAlert, documentation='TODO', location=pyxb.utils.utility.Location('/home/gberg/code/src/fstr/darwinpush/xsd/rttiPPTTrainAlerts_v1.xsd', 65, 3)))

TrainAlert._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'AlertText'), pyxb.binding.datatypes.string, scope=TrainAlert, documentation='TODO', location=pyxb.utils.utility.Location('/home/gberg/code/src/fstr/darwinpush/xsd/rttiPPTTrainAlerts_v1.xsd', 70, 3)))

TrainAlert._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'Audience'), AlertAudienceType, scope=TrainAlert, documentation='TODO', location=pyxb.utils.utility.Location('/home/gberg/code/src/fstr/darwinpush/xsd/rttiPPTTrainAlerts_v1.xsd', 75, 3)))

TrainAlert._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'AlertType'), AlertType, scope=TrainAlert, documentation='TODO', location=pyxb.utils.utility.Location('/home/gberg/code/src/fstr/darwinpush/xsd/rttiPPTTrainAlerts_v1.xsd', 80, 3)))

TrainAlert._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'CopiedFromAlertID'), pyxb.binding.datatypes.string, scope=TrainAlert, documentation='TODO', location=pyxb.utils.utility.Location('/home/gberg/code/src/fstr/darwinpush/xsd/rttiPPTTrainAlerts_v1.xsd', 85, 3)))

TrainAlert._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'CopiedFromSource'), pyxb.binding.datatypes.string, scope=TrainAlert, documentation='TODO', location=pyxb.utils.utility.Location('/home/gberg/code/src/fstr/darwinpush/xsd/rttiPPTTrainAlerts_v1.xsd', 90, 3)))

def _BuildAutomaton ():
    # Remove this helper function from the namespace after it is invoked
    global _BuildAutomaton
    del _BuildAutomaton
    import pyxb.utils.fac as fac

    counters = set()
    cc_0 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('/home/gberg/code/src/fstr/darwinpush/xsd/rttiPPTTrainAlerts_v1.xsd', 85, 3))
    counters.add(cc_0)
    cc_1 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('/home/gberg/code/src/fstr/darwinpush/xsd/rttiPPTTrainAlerts_v1.xsd', 90, 3))
    counters.add(cc_1)
    states = []
    final_update = None
    symbol = pyxb.binding.content.ElementUse(TrainAlert._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'AlertID')), pyxb.utils.utility.Location('/home/gberg/code/src/fstr/darwinpush/xsd/rttiPPTTrainAlerts_v1.xsd', 40, 3))
    st_0 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_0)
    final_update = None
    symbol = pyxb.binding.content.ElementUse(TrainAlert._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'AlertServices')), pyxb.utils.utility.Location('/home/gberg/code/src/fstr/darwinpush/xsd/rttiPPTTrainAlerts_v1.xsd', 45, 3))
    st_1 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_1)
    final_update = None
    symbol = pyxb.binding.content.ElementUse(TrainAlert._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'SendAlertBySMS')), pyxb.utils.utility.Location('/home/gberg/code/src/fstr/darwinpush/xsd/rttiPPTTrainAlerts_v1.xsd', 50, 3))
    st_2 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_2)
    final_update = None
    symbol = pyxb.binding.content.ElementUse(TrainAlert._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'SendAlertByEmail')), pyxb.utils.utility.Location('/home/gberg/code/src/fstr/darwinpush/xsd/rttiPPTTrainAlerts_v1.xsd', 55, 3))
    st_3 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_3)
    final_update = None
    symbol = pyxb.binding.content.ElementUse(TrainAlert._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'SendAlertByTwitter')), pyxb.utils.utility.Location('/home/gberg/code/src/fstr/darwinpush/xsd/rttiPPTTrainAlerts_v1.xsd', 60, 3))
    st_4 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_4)
    final_update = None
    symbol = pyxb.binding.content.ElementUse(TrainAlert._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'Source')), pyxb.utils.utility.Location('/home/gberg/code/src/fstr/darwinpush/xsd/rttiPPTTrainAlerts_v1.xsd', 65, 3))
    st_5 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_5)
    final_update = None
    symbol = pyxb.binding.content.ElementUse(TrainAlert._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'AlertText')), pyxb.utils.utility.Location('/home/gberg/code/src/fstr/darwinpush/xsd/rttiPPTTrainAlerts_v1.xsd', 70, 3))
    st_6 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_6)
    final_update = None
    symbol = pyxb.binding.content.ElementUse(TrainAlert._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'Audience')), pyxb.utils.utility.Location('/home/gberg/code/src/fstr/darwinpush/xsd/rttiPPTTrainAlerts_v1.xsd', 75, 3))
    st_7 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_7)
    final_update = set()
    symbol = pyxb.binding.content.ElementUse(TrainAlert._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'AlertType')), pyxb.utils.utility.Location('/home/gberg/code/src/fstr/darwinpush/xsd/rttiPPTTrainAlerts_v1.xsd', 80, 3))
    st_8 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_8)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_0, False))
    symbol = pyxb.binding.content.ElementUse(TrainAlert._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'CopiedFromAlertID')), pyxb.utils.utility.Location('/home/gberg/code/src/fstr/darwinpush/xsd/rttiPPTTrainAlerts_v1.xsd', 85, 3))
    st_9 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_9)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_1, False))
    symbol = pyxb.binding.content.ElementUse(TrainAlert._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'CopiedFromSource')), pyxb.utils.utility.Location('/home/gberg/code/src/fstr/darwinpush/xsd/rttiPPTTrainAlerts_v1.xsd', 90, 3))
    st_10 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_10)
    transitions = []
    transitions.append(fac.Transition(st_1, [
         ]))
    st_0._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_2, [
         ]))
    st_1._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_3, [
         ]))
    st_2._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_4, [
         ]))
    st_3._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_5, [
         ]))
    st_4._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_6, [
         ]))
    st_5._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_7, [
         ]))
    st_6._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_8, [
         ]))
    st_7._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_9, [
         ]))
    transitions.append(fac.Transition(st_10, [
         ]))
    st_8._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_9, [
        fac.UpdateInstruction(cc_0, True) ]))
    transitions.append(fac.Transition(st_10, [
        fac.UpdateInstruction(cc_0, False) ]))
    st_9._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_10, [
        fac.UpdateInstruction(cc_1, True) ]))
    st_10._set_transitionSet(transitions)
    return fac.Automaton(states, counters, False, containing_state=None)
TrainAlert._Automaton = _BuildAutomaton()




AlertServices._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'AlertService'), AlertService, scope=AlertServices, documentation='TODO', location=pyxb.utils.utility.Location('/home/gberg/code/src/fstr/darwinpush/xsd/rttiPPTTrainAlerts_v1.xsd', 129, 3)))

def _BuildAutomaton_ ():
    # Remove this helper function from the namespace after it is invoked
    global _BuildAutomaton_
    del _BuildAutomaton_
    import pyxb.utils.fac as fac

    counters = set()
    cc_0 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('/home/gberg/code/src/fstr/darwinpush/xsd/rttiPPTTrainAlerts_v1.xsd', 129, 3))
    counters.add(cc_0)
    states = []
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_0, False))
    symbol = pyxb.binding.content.ElementUse(AlertServices._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'AlertService')), pyxb.utils.utility.Location('/home/gberg/code/src/fstr/darwinpush/xsd/rttiPPTTrainAlerts_v1.xsd', 129, 3))
    st_0 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_0)
    transitions = []
    transitions.append(fac.Transition(st_0, [
        fac.UpdateInstruction(cc_0, True) ]))
    st_0._set_transitionSet(transitions)
    return fac.Automaton(states, counters, True, containing_state=None)
AlertServices._Automaton = _BuildAutomaton_()




AlertService._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'Location'), pyxb.binding.datatypes.string, scope=AlertService, documentation='TODO', location=pyxb.utils.utility.Location('/home/gberg/code/src/fstr/darwinpush/xsd/rttiPPTTrainAlerts_v1.xsd', 102, 3)))

def _BuildAutomaton_2 ():
    # Remove this helper function from the namespace after it is invoked
    global _BuildAutomaton_2
    del _BuildAutomaton_2
    import pyxb.utils.fac as fac

    counters = set()
    states = []
    final_update = set()
    symbol = pyxb.binding.content.ElementUse(AlertService._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'Location')), pyxb.utils.utility.Location('/home/gberg/code/src/fstr/darwinpush/xsd/rttiPPTTrainAlerts_v1.xsd', 102, 3))
    st_0 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_0)
    transitions = []
    transitions.append(fac.Transition(st_0, [
         ]))
    st_0._set_transitionSet(transitions)
    return fac.Automaton(states, counters, False, containing_state=None)
AlertService._Automaton = _BuildAutomaton_2()




import pytz
from datetime import datetime, timedelta

def timezone_for_date_and_time(d, t):
    tz = pytz.timezone("Europe/London")
    dt = pytz.utc.localize(datetime.combine(d, t))
    if dt.astimezone(tz).utcoffset().seconds / 3600 == 1:
        # Think the timezone below is wrong? Read the whole of the linked file, then think again.
        # https://github.com/eggert/tz/blob/master/etcetera
        return pytz.timezone("Etc/GMT-1")
    else:
        return pytz.timezone("Etc/GMT")





# ./darwinpush/xb/raw/binding.py
# -*- coding: utf-8 -*-
# PyXB bindings for NM:9d19614910a8e83cbb93a86fc981bfb16ed4834a
# Generated 2015-04-23 16:42:14.515396 by PyXB version 1.2.4 using Python 3.4.1.final.0
# Namespace http://www.thalesgroup.com/rtti/XmlRefData/v3

from __future__ import unicode_literals
import pyxb
import pyxb.binding
import pyxb.binding.saxer
import io
import pyxb.utils.utility
import pyxb.utils.domutils
import sys
import pyxb.utils.six as _six

# Unique identifier for bindings created at the same time
_GenerationUID = pyxb.utils.utility.UniqueIdentifier('urn:uuid:5049f1de-e9cf-11e4-bb50-a0481ca50ab0')

# Version of PyXB used to generate the bindings
_PyXBVersion = '1.2.4'
# Generated bindings are not compatible across PyXB versions
if pyxb.__version__ != _PyXBVersion:
    raise pyxb.PyXBVersionError(_PyXBVersion)

# Import bindings for namespaces imported into schema
import pyxb.binding.datatypes

# NOTE: All namespace declarations are reserved within the binding
Namespace = pyxb.namespace.NamespaceForURI('http://www.thalesgroup.com/rtti/XmlRefData/v3', create_if_missing=True)
Namespace.configureCategories(['typeBinding', 'elementBinding'])

def CreateFromDocument (xml_text, default_namespace=None, location_base=None):
    """Parse the given XML and use the document element to create a
    Python instance.

    @param xml_text An XML document.  This should be data (Python 2
    str or Python 3 bytes), or a text (Python 2 unicode or Python 3
    str) in the L{pyxb._InputEncoding} encoding.

    @keyword default_namespace The L{pyxb.Namespace} instance to use as the
    default namespace where there is no default namespace in scope.
    If unspecified or C{None}, the namespace of the module containing
    this function will be used.

    @keyword location_base: An object to be recorded as the base of all
    L{pyxb.utils.utility.Location} instances associated with events and
    objects handled by the parser.  You might pass the URI from which
    the document was obtained.
    """

    if pyxb.XMLStyle_saxer != pyxb._XMLStyle:
        dom = pyxb.utils.domutils.StringToDOM(xml_text)
        return CreateFromDOM(dom.documentElement, default_namespace=default_namespace)
    if default_namespace is None:
        default_namespace = Namespace.fallbackNamespace()
    saxer = pyxb.binding.saxer.make_parser(fallback_namespace=default_namespace, location_base=location_base)
    handler = saxer.getContentHandler()
    xmld = xml_text
    if isinstance(xmld, _six.text_type):
        xmld = xmld.encode(pyxb._InputEncoding)
    saxer.parse(io.BytesIO(xmld))
    instance = handler.rootObject()
    return instance

def CreateFromDOM (node, default_namespace=None):
    """Create a Python instance from the given DOM node.
    The node tag must correspond to an element declaration in this module.

    @deprecated: Forcing use of DOM interface is unnecessary; use L{CreateFromDocument}."""
    if default_namespace is None:
        default_namespace = Namespace.fallbackNamespace()
    return pyxb.binding.basis.element.AnyCreateFromDOM(node, default_namespace)


# Atomic simple type: {http://www.thalesgroup.com/rtti/XmlRefData/v3}TimetableIdType
class TimetableIdType (pyxb.binding.datatypes.string):

    """Unique Timetable identifier """

    _ExpandedName = pyxb.namespace.ExpandedName(Namespace, 'TimetableIdType')
    _XSDLocation = pyxb.utils.utility.Location('/home/gberg/code/src/fstr/darwinpush/xsd/rttiCTTReferenceSchema_v3.xsd', 23, 1)
    _Documentation = 'Unique Timetable identifier '
TimetableIdType._CF_length = pyxb.binding.facets.CF_length(value=pyxb.binding.datatypes.nonNegativeInteger(14))
TimetableIdType._InitializeFacetMap(TimetableIdType._CF_length)
Namespace.addCategoryObject('typeBinding', 'TimetableIdType', TimetableIdType)

# Atomic simple type: {http://www.thalesgroup.com/rtti/XmlRefData/v3}LocationNameType
class LocationNameType (pyxb.binding.datatypes.string):

    """English name of the location"""

    _ExpandedName = pyxb.namespace.ExpandedName(Namespace, 'LocationNameType')
    _XSDLocation = pyxb.utils.utility.Location('/home/gberg/code/src/fstr/darwinpush/xsd/rttiCTTReferenceSchema_v3.xsd', 31, 1)
    _Documentation = 'English name of the location'
LocationNameType._CF_minLength = pyxb.binding.facets.CF_minLength(value=pyxb.binding.datatypes.nonNegativeInteger(1))
LocationNameType._CF_whiteSpace = pyxb.binding.facets.CF_whiteSpace(value=pyxb.binding.facets._WhiteSpace_enum.preserve)
LocationNameType._CF_maxLength = pyxb.binding.facets.CF_maxLength(value=pyxb.binding.datatypes.nonNegativeInteger(30))
LocationNameType._InitializeFacetMap(LocationNameType._CF_minLength,
   LocationNameType._CF_whiteSpace,
   LocationNameType._CF_maxLength)
Namespace.addCategoryObject('typeBinding', 'LocationNameType', LocationNameType)

# Atomic simple type: {http://www.thalesgroup.com/rtti/XmlRefData/v3}TiplocType
class TiplocType (pyxb.binding.datatypes.string):

    """Tiploc Type (This is the short version of a TIPLOC - without spaces)"""

    _ExpandedName = pyxb.namespace.ExpandedName(Namespace, 'TiplocType')
    _XSDLocation = pyxb.utils.utility.Location('/home/gberg/code/src/fstr/darwinpush/xsd/rttiCTTReferenceSchema_v3.xsd', 41, 1)
    _Documentation = 'Tiploc Type (This is the short version of a TIPLOC - without spaces)'
TiplocType._CF_maxLength = pyxb.binding.facets.CF_maxLength(value=pyxb.binding.datatypes.nonNegativeInteger(7))
TiplocType._InitializeFacetMap(TiplocType._CF_maxLength)
Namespace.addCategoryObject('typeBinding', 'TiplocType', TiplocType)

# Atomic simple type: {http://www.thalesgroup.com/rtti/XmlRefData/v3}TOCType
class TOCType (pyxb.binding.datatypes.string):

    """ATOC Code Type"""

    _ExpandedName = pyxb.namespace.ExpandedName(Namespace, 'TOCType')
    _XSDLocation = pyxb.utils.utility.Location('/home/gberg/code/src/fstr/darwinpush/xsd/rttiCTTReferenceSchema_v3.xsd', 49, 1)
    _Documentation = 'ATOC Code Type'
TOCType._CF_length = pyxb.binding.facets.CF_length(value=pyxb.binding.datatypes.nonNegativeInteger(2))
TOCType._InitializeFacetMap(TOCType._CF_length)
Namespace.addCategoryObject('typeBinding', 'TOCType', TOCType)

# Atomic simple type: {http://www.thalesgroup.com/rtti/XmlRefData/v3}CrsType
class CrsType (pyxb.binding.datatypes.string):

    """CRS Code Type"""

    _ExpandedName = pyxb.namespace.ExpandedName(Namespace, 'CrsType')
    _XSDLocation = pyxb.utils.utility.Location('/home/gberg/code/src/fstr/darwinpush/xsd/rttiCTTReferenceSchema_v3.xsd', 57, 1)
    _Documentation = 'CRS Code Type'
CrsType._CF_length = pyxb.binding.facets.CF_length(value=pyxb.binding.datatypes.nonNegativeInteger(3))
CrsType._InitializeFacetMap(CrsType._CF_length)
Namespace.addCategoryObject('typeBinding', 'CrsType', CrsType)

# Atomic simple type: {http://www.thalesgroup.com/rtti/XmlRefData/v3}ReasonCodeType
class ReasonCodeType (pyxb.binding.datatypes.int):

    """Reason code"""

    _ExpandedName = pyxb.namespace.ExpandedName(Namespace, 'ReasonCodeType')
    _XSDLocation = pyxb.utils.utility.Location('/home/gberg/code/src/fstr/darwinpush/xsd/rttiCTTReferenceSchema_v3.xsd', 65, 1)
    _Documentation = 'Reason code'
ReasonCodeType._InitializeFacetMap()
Namespace.addCategoryObject('typeBinding', 'ReasonCodeType', ReasonCodeType)

# Atomic simple type: {http://www.thalesgroup.com/rtti/XmlRefData/v3}ReasonTextType
class ReasonTextType (pyxb.binding.datatypes.string):

    """Reason as text"""

    _ExpandedName = pyxb.namespace.ExpandedName(Namespace, 'ReasonTextType')
    _XSDLocation = pyxb.utils.utility.Location('/home/gberg/code/src/fstr/darwinpush/xsd/rttiCTTReferenceSchema_v3.xsd', 71, 1)
    _Documentation = 'Reason as text'
ReasonTextType._CF_minLength = pyxb.binding.facets.CF_minLength(value=pyxb.binding.datatypes.nonNegativeInteger(1))
ReasonTextType._CF_maxLength = pyxb.binding.facets.CF_maxLength(value=pyxb.binding.datatypes.nonNegativeInteger(256))
ReasonTextType._InitializeFacetMap(ReasonTextType._CF_minLength,
   ReasonTextType._CF_maxLength)
Namespace.addCategoryObject('typeBinding', 'ReasonTextType', ReasonTextType)

# Atomic simple type: {http://www.thalesgroup.com/rtti/XmlRefData/v3}ViaTextType
class ViaTextType (pyxb.binding.datatypes.string):

    """The text displayed for a via"""

    _ExpandedName = pyxb.namespace.ExpandedName(Namespace, 'ViaTextType')
    _XSDLocation = pyxb.utils.utility.Location('/home/gberg/code/src/fstr/darwinpush/xsd/rttiCTTReferenceSchema_v3.xsd', 80, 1)
    _Documentation = 'The text displayed for a via'
ViaTextType._CF_minLength = pyxb.binding.facets.CF_minLength(value=pyxb.binding.datatypes.nonNegativeInteger(1))
ViaTextType._CF_maxLength = pyxb.binding.facets.CF_maxLength(value=pyxb.binding.datatypes.nonNegativeInteger(256))
ViaTextType._InitializeFacetMap(ViaTextType._CF_minLength,
   ViaTextType._CF_maxLength)
Namespace.addCategoryObject('typeBinding', 'ViaTextType', ViaTextType)

# Atomic simple type: {http://www.thalesgroup.com/rtti/XmlRefData/v3}TOCNameType
class TOCNameType (pyxb.binding.datatypes.string):

    """The name of the TOC"""

    _ExpandedName = pyxb.namespace.ExpandedName(Namespace, 'TOCNameType')
    _XSDLocation = pyxb.utils.utility.Location('/home/gberg/code/src/fstr/darwinpush/xsd/rttiCTTReferenceSchema_v3.xsd', 89, 1)
    _Documentation = 'The name of the TOC'
TOCNameType._CF_minLength = pyxb.binding.facets.CF_minLength(value=pyxb.binding.datatypes.nonNegativeInteger(0))
TOCNameType._CF_maxLength = pyxb.binding.facets.CF_maxLength(value=pyxb.binding.datatypes.nonNegativeInteger(256))
TOCNameType._InitializeFacetMap(TOCNameType._CF_minLength,
   TOCNameType._CF_maxLength)
Namespace.addCategoryObject('typeBinding', 'TOCNameType', TOCNameType)

# Atomic simple type: {http://www.thalesgroup.com/rtti/XmlRefData/v3}UrlType
class UrlType (pyxb.binding.datatypes.string):

    """A URL"""

    _ExpandedName = pyxb.namespace.ExpandedName(Namespace, 'UrlType')
    _XSDLocation = pyxb.utils.utility.Location('/home/gberg/code/src/fstr/darwinpush/xsd/rttiCTTReferenceSchema_v3.xsd', 98, 1)
    _Documentation = 'A URL'
UrlType._CF_minLength = pyxb.binding.facets.CF_minLength(value=pyxb.binding.datatypes.nonNegativeInteger(0))
UrlType._CF_maxLength = pyxb.binding.facets.CF_maxLength(value=pyxb.binding.datatypes.nonNegativeInteger(512))
UrlType._InitializeFacetMap(UrlType._CF_minLength,
   UrlType._CF_maxLength)
Namespace.addCategoryObject('typeBinding', 'UrlType', UrlType)

# Atomic simple type: {http://www.thalesgroup.com/rtti/XmlRefData/v3}CISSourceCode
class CISSourceCode (pyxb.binding.datatypes.string):

    """A CIS source code"""

    _ExpandedName = pyxb.namespace.ExpandedName(Namespace, 'CISSourceCode')
    _XSDLocation = pyxb.utils.utility.Location('/home/gberg/code/src/fstr/darwinpush/xsd/rttiCTTReferenceSchema_v3.xsd', 107, 1)
    _Documentation = 'A CIS source code'
CISSourceCode._CF_length = pyxb.binding.facets.CF_length(value=pyxb.binding.datatypes.nonNegativeInteger(4))
CISSourceCode._InitializeFacetMap(CISSourceCode._CF_length)
Namespace.addCategoryObject('typeBinding', 'CISSourceCode', CISSourceCode)

# Atomic simple type: {http://www.thalesgroup.com/rtti/XmlRefData/v3}CISSourceName
class CISSourceName (pyxb.binding.datatypes.string):

    """A CIS source name"""

    _ExpandedName = pyxb.namespace.ExpandedName(Namespace, 'CISSourceName')
    _XSDLocation = pyxb.utils.utility.Location('/home/gberg/code/src/fstr/darwinpush/xsd/rttiCTTReferenceSchema_v3.xsd', 115, 1)
    _Documentation = 'A CIS source name'
CISSourceName._CF_minLength = pyxb.binding.facets.CF_minLength(value=pyxb.binding.datatypes.nonNegativeInteger(0))
CISSourceName._CF_maxLength = pyxb.binding.facets.CF_maxLength(value=pyxb.binding.datatypes.nonNegativeInteger(30))
CISSourceName._InitializeFacetMap(CISSourceName._CF_minLength,
   CISSourceName._CF_maxLength)
Namespace.addCategoryObject('typeBinding', 'CISSourceName', CISSourceName)

# Complex type [anonymous] with content type ELEMENT_ONLY
class CTD_ANON (pyxb.binding.basis.complexTypeDefinition):
    """Complex type [anonymous] with content type ELEMENT_ONLY"""
    _TypeDefinition = None
    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_ELEMENT_ONLY
    _Abstract = False
    _ExpandedName = None
    _XSDLocation = pyxb.utils.utility.Location('/home/gberg/code/src/fstr/darwinpush/xsd/rttiCTTReferenceSchema_v3.xsd', 134, 5)
    _ElementMap = {}
    _AttributeMap = {}
    # Base type is pyxb.binding.datatypes.anyType
    
    # Element {http://www.thalesgroup.com/rtti/XmlRefData/v3}Reason uses Python identifier Reason
    __Reason = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'Reason'), 'Reason', '__httpwww_thalesgroup_comrttiXmlRefDatav3_CTD_ANON_httpwww_thalesgroup_comrttiXmlRefDatav3Reason', True, pyxb.utils.utility.Location('/home/gberg/code/src/fstr/darwinpush/xsd/rttiCTTReferenceSchema_v3.xsd', 198, 1), )

    
    Reason = property(__Reason.value, __Reason.set, None, 'Defines a mapping bewteen a reason code and the corresponding text')

    _ElementMap.update({
        __Reason.name() : __Reason
    })
    _AttributeMap.update({
        
    })



# Complex type [anonymous] with content type ELEMENT_ONLY
class CTD_ANON_ (pyxb.binding.basis.complexTypeDefinition):
    """Complex type [anonymous] with content type ELEMENT_ONLY"""
    _TypeDefinition = None
    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_ELEMENT_ONLY
    _Abstract = False
    _ExpandedName = None
    _XSDLocation = pyxb.utils.utility.Location('/home/gberg/code/src/fstr/darwinpush/xsd/rttiCTTReferenceSchema_v3.xsd', 141, 5)
    _ElementMap = {}
    _AttributeMap = {}
    # Base type is pyxb.binding.datatypes.anyType
    
    # Element {http://www.thalesgroup.com/rtti/XmlRefData/v3}Reason uses Python identifier Reason
    __Reason = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'Reason'), 'Reason', '__httpwww_thalesgroup_comrttiXmlRefDatav3_CTD_ANON__httpwww_thalesgroup_comrttiXmlRefDatav3Reason', True, pyxb.utils.utility.Location('/home/gberg/code/src/fstr/darwinpush/xsd/rttiCTTReferenceSchema_v3.xsd', 198, 1), )

    
    Reason = property(__Reason.value, __Reason.set, None, 'Defines a mapping bewteen a reason code and the corresponding text')

    _ElementMap.update({
        __Reason.name() : __Reason
    })
    _AttributeMap.update({
        
    })



# Complex type [anonymous] with content type ELEMENT_ONLY
class CTD_ANON_2 (pyxb.binding.basis.complexTypeDefinition):
    """Push Port Timetable Reference Schema """
    _TypeDefinition = None
    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_ELEMENT_ONLY
    _Abstract = False
    _ExpandedName = None
    _XSDLocation = pyxb.utils.utility.Location('/home/gberg/code/src/fstr/darwinpush/xsd/rttiCTTReferenceSchema_v3.xsd', 129, 2)
    _ElementMap = {}
    _AttributeMap = {}
    # Base type is pyxb.binding.datatypes.anyType
    
    # Element {http://www.thalesgroup.com/rtti/XmlRefData/v3}LateRunningReasons uses Python identifier LateRunningReasons
    __LateRunningReasons = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'LateRunningReasons'), 'LateRunningReasons', '__httpwww_thalesgroup_comrttiXmlRefDatav3_CTD_ANON_2_httpwww_thalesgroup_comrttiXmlRefDatav3LateRunningReasons', False, pyxb.utils.utility.Location('/home/gberg/code/src/fstr/darwinpush/xsd/rttiCTTReferenceSchema_v3.xsd', 133, 4), )

    
    LateRunningReasons = property(__LateRunningReasons.value, __LateRunningReasons.set, None, None)

    
    # Element {http://www.thalesgroup.com/rtti/XmlRefData/v3}CancellationReasons uses Python identifier CancellationReasons
    __CancellationReasons = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'CancellationReasons'), 'CancellationReasons', '__httpwww_thalesgroup_comrttiXmlRefDatav3_CTD_ANON_2_httpwww_thalesgroup_comrttiXmlRefDatav3CancellationReasons', False, pyxb.utils.utility.Location('/home/gberg/code/src/fstr/darwinpush/xsd/rttiCTTReferenceSchema_v3.xsd', 140, 4), )

    
    CancellationReasons = property(__CancellationReasons.value, __CancellationReasons.set, None, None)

    
    # Element {http://www.thalesgroup.com/rtti/XmlRefData/v3}LocationRef uses Python identifier LocationRef
    __LocationRef = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'LocationRef'), 'LocationRef', '__httpwww_thalesgroup_comrttiXmlRefDatav3_CTD_ANON_2_httpwww_thalesgroup_comrttiXmlRefDatav3LocationRef', True, pyxb.utils.utility.Location('/home/gberg/code/src/fstr/darwinpush/xsd/rttiCTTReferenceSchema_v3.xsd', 153, 1), )

    
    LocationRef = property(__LocationRef.value, __LocationRef.set, None, 'Defines a location')

    
    # Element {http://www.thalesgroup.com/rtti/XmlRefData/v3}TocRef uses Python identifier TocRef
    __TocRef = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'TocRef'), 'TocRef', '__httpwww_thalesgroup_comrttiXmlRefDatav3_CTD_ANON_2_httpwww_thalesgroup_comrttiXmlRefDatav3TocRef', True, pyxb.utils.utility.Location('/home/gberg/code/src/fstr/darwinpush/xsd/rttiCTTReferenceSchema_v3.xsd', 180, 1), )

    
    TocRef = property(__TocRef.value, __TocRef.set, None, 'Defines a mapping between a TOC and a displayable name')

    
    # Element {http://www.thalesgroup.com/rtti/XmlRefData/v3}Via uses Python identifier Via
    __Via = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'Via'), 'Via', '__httpwww_thalesgroup_comrttiXmlRefDatav3_CTD_ANON_2_httpwww_thalesgroup_comrttiXmlRefDatav3Via', True, pyxb.utils.utility.Location('/home/gberg/code/src/fstr/darwinpush/xsd/rttiCTTReferenceSchema_v3.xsd', 207, 1), )

    
    Via = property(__Via.value, __Via.set, None, 'Defines the locations a journey must be viewed from, go to and pass through for the corresponding via text to be displayed')

    
    # Element {http://www.thalesgroup.com/rtti/XmlRefData/v3}CISSource uses Python identifier CISSource
    __CISSource = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'CISSource'), 'CISSource', '__httpwww_thalesgroup_comrttiXmlRefDatav3_CTD_ANON_2_httpwww_thalesgroup_comrttiXmlRefDatav3CISSource', True, pyxb.utils.utility.Location('/home/gberg/code/src/fstr/darwinpush/xsd/rttiCTTReferenceSchema_v3.xsd', 239, 1), )

    
    CISSource = property(__CISSource.value, __CISSource.set, None, 'Defines the mapping between 4 letter CIS codes and the CIS name')

    
    # Attribute timetableId uses Python identifier timetableId
    __timetableId = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, 'timetableId'), 'timetableId', '__httpwww_thalesgroup_comrttiXmlRefDatav3_CTD_ANON_2_timetableId', TimetableIdType, required=True)
    __timetableId._DeclarationLocation = pyxb.utils.utility.Location('/home/gberg/code/src/fstr/darwinpush/xsd/rttiCTTReferenceSchema_v3.xsd', 150, 3)
    __timetableId._UseLocation = pyxb.utils.utility.Location('/home/gberg/code/src/fstr/darwinpush/xsd/rttiCTTReferenceSchema_v3.xsd', 150, 3)
    
    timetableId = property(__timetableId.value, __timetableId.set, None, None)

    _ElementMap.update({
        __LateRunningReasons.name() : __LateRunningReasons,
        __CancellationReasons.name() : __CancellationReasons,
        __LocationRef.name() : __LocationRef,
        __TocRef.name() : __TocRef,
        __Via.name() : __Via,
        __CISSource.name() : __CISSource
    })
    _AttributeMap.update({
        __timetableId.name() : __timetableId
    })



# Complex type [anonymous] with content type EMPTY
class CTD_ANON_3 (pyxb.binding.basis.complexTypeDefinition):
    """Defines a location"""
    _TypeDefinition = None
    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_EMPTY
    _Abstract = False
    _ExpandedName = None
    _XSDLocation = pyxb.utils.utility.Location('/home/gberg/code/src/fstr/darwinpush/xsd/rttiCTTReferenceSchema_v3.xsd', 157, 2)
    _ElementMap = {}
    _AttributeMap = {}
    # Base type is pyxb.binding.datatypes.anyType
    
    # Attribute tpl uses Python identifier tpl
    __tpl = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, 'tpl'), 'tpl', '__httpwww_thalesgroup_comrttiXmlRefDatav3_CTD_ANON_3_tpl', TiplocType, required=True)
    __tpl._DeclarationLocation = pyxb.utils.utility.Location('/home/gberg/code/src/fstr/darwinpush/xsd/rttiCTTReferenceSchema_v3.xsd', 158, 3)
    __tpl._UseLocation = pyxb.utils.utility.Location('/home/gberg/code/src/fstr/darwinpush/xsd/rttiCTTReferenceSchema_v3.xsd', 158, 3)
    
    tpl = property(__tpl.value, __tpl.set, None, 'TIPLOC code')

    
    # Attribute crs uses Python identifier crs
    __crs = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, 'crs'), 'crs', '__httpwww_thalesgroup_comrttiXmlRefDatav3_CTD_ANON_3_crs', CrsType)
    __crs._DeclarationLocation = pyxb.utils.utility.Location('/home/gberg/code/src/fstr/darwinpush/xsd/rttiCTTReferenceSchema_v3.xsd', 163, 3)
    __crs._UseLocation = pyxb.utils.utility.Location('/home/gberg/code/src/fstr/darwinpush/xsd/rttiCTTReferenceSchema_v3.xsd', 163, 3)
    
    crs = property(__crs.value, __crs.set, None, 'CRS code')

    
    # Attribute toc uses Python identifier toc
    __toc = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, 'toc'), 'toc', '__httpwww_thalesgroup_comrttiXmlRefDatav3_CTD_ANON_3_toc', TOCType)
    __toc._DeclarationLocation = pyxb.utils.utility.Location('/home/gberg/code/src/fstr/darwinpush/xsd/rttiCTTReferenceSchema_v3.xsd', 168, 3)
    __toc._UseLocation = pyxb.utils.utility.Location('/home/gberg/code/src/fstr/darwinpush/xsd/rttiCTTReferenceSchema_v3.xsd', 168, 3)
    
    toc = property(__toc.value, __toc.set, None, 'Train Operating Company that manages the station (may be non-TOC code, e.g. Network Rail).')

    
    # Attribute locname uses Python identifier locname
    __locname = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, 'locname'), 'locname', '__httpwww_thalesgroup_comrttiXmlRefDatav3_CTD_ANON_3_locname', LocationNameType, required=True)
    __locname._DeclarationLocation = pyxb.utils.utility.Location('/home/gberg/code/src/fstr/darwinpush/xsd/rttiCTTReferenceSchema_v3.xsd', 173, 3)
    __locname._UseLocation = pyxb.utils.utility.Location('/home/gberg/code/src/fstr/darwinpush/xsd/rttiCTTReferenceSchema_v3.xsd', 173, 3)
    
    locname = property(__locname.value, __locname.set, None, 'English name of location')

    _ElementMap.update({
        
    })
    _AttributeMap.update({
        __tpl.name() : __tpl,
        __crs.name() : __crs,
        __toc.name() : __toc,
        __locname.name() : __locname
    })



# Complex type [anonymous] with content type EMPTY
class CTD_ANON_4 (pyxb.binding.basis.complexTypeDefinition):
    """Defines a mapping between a TOC and a displayable name"""
    _TypeDefinition = None
    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_EMPTY
    _Abstract = False
    _ExpandedName = None
    _XSDLocation = pyxb.utils.utility.Location('/home/gberg/code/src/fstr/darwinpush/xsd/rttiCTTReferenceSchema_v3.xsd', 184, 2)
    _ElementMap = {}
    _AttributeMap = {}
    # Base type is pyxb.binding.datatypes.anyType
    
    # Attribute toc uses Python identifier toc
    __toc = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, 'toc'), 'toc', '__httpwww_thalesgroup_comrttiXmlRefDatav3_CTD_ANON_4_toc', TOCType, required=True)
    __toc._DeclarationLocation = pyxb.utils.utility.Location('/home/gberg/code/src/fstr/darwinpush/xsd/rttiCTTReferenceSchema_v3.xsd', 185, 3)
    __toc._UseLocation = pyxb.utils.utility.Location('/home/gberg/code/src/fstr/darwinpush/xsd/rttiCTTReferenceSchema_v3.xsd', 185, 3)
    
    toc = property(__toc.value, __toc.set, None, 'The TOC code')

    
    # Attribute tocname uses Python identifier tocname
    __tocname = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, 'tocname'), 'tocname', '__httpwww_thalesgroup_comrttiXmlRefDatav3_CTD_ANON_4_tocname', TOCNameType, required=True)
    __tocname._DeclarationLocation = pyxb.utils.utility.Location('/home/gberg/code/src/fstr/darwinpush/xsd/rttiCTTReferenceSchema_v3.xsd', 190, 3)
    __tocname._UseLocation = pyxb.utils.utility.Location('/home/gberg/code/src/fstr/darwinpush/xsd/rttiCTTReferenceSchema_v3.xsd', 190, 3)
    
    tocname = property(__tocname.value, __tocname.set, None, 'The name of the TOC')

    
    # Attribute url uses Python identifier url
    __url = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, 'url'), 'url', '__httpwww_thalesgroup_comrttiXmlRefDatav3_CTD_ANON_4_url', UrlType)
    __url._DeclarationLocation = pyxb.utils.utility.Location('/home/gberg/code/src/fstr/darwinpush/xsd/rttiCTTReferenceSchema_v3.xsd', 195, 3)
    __url._UseLocation = pyxb.utils.utility.Location('/home/gberg/code/src/fstr/darwinpush/xsd/rttiCTTReferenceSchema_v3.xsd', 195, 3)
    
    url = property(__url.value, __url.set, None, None)

    _ElementMap.update({
        
    })
    _AttributeMap.update({
        __toc.name() : __toc,
        __tocname.name() : __tocname,
        __url.name() : __url
    })



# Complex type [anonymous] with content type EMPTY
class CTD_ANON_5 (pyxb.binding.basis.complexTypeDefinition):
    """Defines a mapping bewteen a reason code and the corresponding text"""
    _TypeDefinition = None
    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_EMPTY
    _Abstract = False
    _ExpandedName = None
    _XSDLocation = pyxb.utils.utility.Location('/home/gberg/code/src/fstr/darwinpush/xsd/rttiCTTReferenceSchema_v3.xsd', 202, 2)
    _ElementMap = {}
    _AttributeMap = {}
    # Base type is pyxb.binding.datatypes.anyType
    
    # Attribute code uses Python identifier code
    __code = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, 'code'), 'code', '__httpwww_thalesgroup_comrttiXmlRefDatav3_CTD_ANON_5_code', ReasonCodeType, required=True)
    __code._DeclarationLocation = pyxb.utils.utility.Location('/home/gberg/code/src/fstr/darwinpush/xsd/rttiCTTReferenceSchema_v3.xsd', 203, 3)
    __code._UseLocation = pyxb.utils.utility.Location('/home/gberg/code/src/fstr/darwinpush/xsd/rttiCTTReferenceSchema_v3.xsd', 203, 3)
    
    code = property(__code.value, __code.set, None, None)

    
    # Attribute reasontext uses Python identifier reasontext
    __reasontext = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, 'reasontext'), 'reasontext', '__httpwww_thalesgroup_comrttiXmlRefDatav3_CTD_ANON_5_reasontext', ReasonTextType, required=True)
    __reasontext._DeclarationLocation = pyxb.utils.utility.Location('/home/gberg/code/src/fstr/darwinpush/xsd/rttiCTTReferenceSchema_v3.xsd', 204, 3)
    __reasontext._UseLocation = pyxb.utils.utility.Location('/home/gberg/code/src/fstr/darwinpush/xsd/rttiCTTReferenceSchema_v3.xsd', 204, 3)
    
    reasontext = property(__reasontext.value, __reasontext.set, None, None)

    _ElementMap.update({
        
    })
    _AttributeMap.update({
        __code.name() : __code,
        __reasontext.name() : __reasontext
    })



# Complex type [anonymous] with content type EMPTY
class CTD_ANON_6 (pyxb.binding.basis.complexTypeDefinition):
    """Defines the locations a journey must be viewed from, go to and pass through for the corresponding via text to be displayed"""
    _TypeDefinition = None
    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_EMPTY
    _Abstract = False
    _ExpandedName = None
    _XSDLocation = pyxb.utils.utility.Location('/home/gberg/code/src/fstr/darwinpush/xsd/rttiCTTReferenceSchema_v3.xsd', 211, 2)
    _ElementMap = {}
    _AttributeMap = {}
    # Base type is pyxb.binding.datatypes.anyType
    
    # Attribute at uses Python identifier at
    __at = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, 'at'), 'at', '__httpwww_thalesgroup_comrttiXmlRefDatav3_CTD_ANON_6_at', CrsType, required=True)
    __at._DeclarationLocation = pyxb.utils.utility.Location('/home/gberg/code/src/fstr/darwinpush/xsd/rttiCTTReferenceSchema_v3.xsd', 212, 3)
    __at._UseLocation = pyxb.utils.utility.Location('/home/gberg/code/src/fstr/darwinpush/xsd/rttiCTTReferenceSchema_v3.xsd', 212, 3)
    
    at = property(__at.value, __at.set, None, 'This is the station for which the via is defined')

    
    # Attribute dest uses Python identifier dest
    __dest = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, 'dest'), 'dest', '__httpwww_thalesgroup_comrttiXmlRefDatav3_CTD_ANON_6_dest', TiplocType, required=True)
    __dest._DeclarationLocation = pyxb.utils.utility.Location('/home/gberg/code/src/fstr/darwinpush/xsd/rttiCTTReferenceSchema_v3.xsd', 217, 3)
    __dest._UseLocation = pyxb.utils.utility.Location('/home/gberg/code/src/fstr/darwinpush/xsd/rttiCTTReferenceSchema_v3.xsd', 217, 3)
    
    dest = property(__dest.value, __dest.set, None, 'The destination of the journey must match this before the via text is valid')

    
    # Attribute loc1 uses Python identifier loc1
    __loc1 = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, 'loc1'), 'loc1', '__httpwww_thalesgroup_comrttiXmlRefDatav3_CTD_ANON_6_loc1', TiplocType, required=True)
    __loc1._DeclarationLocation = pyxb.utils.utility.Location('/home/gberg/code/src/fstr/darwinpush/xsd/rttiCTTReferenceSchema_v3.xsd', 222, 3)
    __loc1._UseLocation = pyxb.utils.utility.Location('/home/gberg/code/src/fstr/darwinpush/xsd/rttiCTTReferenceSchema_v3.xsd', 222, 3)
    
    loc1 = property(__loc1.value, __loc1.set, None, 'The journey must call at this station before the via text is valid.')

    
    # Attribute loc2 uses Python identifier loc2
    __loc2 = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, 'loc2'), 'loc2', '__httpwww_thalesgroup_comrttiXmlRefDatav3_CTD_ANON_6_loc2', TiplocType)
    __loc2._DeclarationLocation = pyxb.utils.utility.Location('/home/gberg/code/src/fstr/darwinpush/xsd/rttiCTTReferenceSchema_v3.xsd', 227, 3)
    __loc2._UseLocation = pyxb.utils.utility.Location('/home/gberg/code/src/fstr/darwinpush/xsd/rttiCTTReferenceSchema_v3.xsd', 227, 3)
    
    loc2 = property(__loc2.value, __loc2.set, None, 'The journey must call at this station (after the call at loc1) before the via text is valid.')

    
    # Attribute viatext uses Python identifier viatext
    __viatext = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, 'viatext'), 'viatext', '__httpwww_thalesgroup_comrttiXmlRefDatav3_CTD_ANON_6_viatext', ViaTextType, required=True)
    __viatext._DeclarationLocation = pyxb.utils.utility.Location('/home/gberg/code/src/fstr/darwinpush/xsd/rttiCTTReferenceSchema_v3.xsd', 232, 3)
    __viatext._UseLocation = pyxb.utils.utility.Location('/home/gberg/code/src/fstr/darwinpush/xsd/rttiCTTReferenceSchema_v3.xsd', 232, 3)
    
    viatext = property(__viatext.value, __viatext.set, None, 'The via text to display if a journey matches the previous attributes')

    _ElementMap.update({
        
    })
    _AttributeMap.update({
        __at.name() : __at,
        __dest.name() : __dest,
        __loc1.name() : __loc1,
        __loc2.name() : __loc2,
        __viatext.name() : __viatext
    })



# Complex type [anonymous] with content type EMPTY
class CTD_ANON_7 (pyxb.binding.basis.complexTypeDefinition):
    """Defines the mapping between 4 letter CIS codes and the CIS name"""
    _TypeDefinition = None
    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_EMPTY
    _Abstract = False
    _ExpandedName = None
    _XSDLocation = pyxb.utils.utility.Location('/home/gberg/code/src/fstr/darwinpush/xsd/rttiCTTReferenceSchema_v3.xsd', 243, 2)
    _ElementMap = {}
    _AttributeMap = {}
    # Base type is pyxb.binding.datatypes.anyType
    
    # Attribute code uses Python identifier code
    __code = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, 'code'), 'code', '__httpwww_thalesgroup_comrttiXmlRefDatav3_CTD_ANON_7_code', CISSourceCode, required=True)
    __code._DeclarationLocation = pyxb.utils.utility.Location('/home/gberg/code/src/fstr/darwinpush/xsd/rttiCTTReferenceSchema_v3.xsd', 244, 3)
    __code._UseLocation = pyxb.utils.utility.Location('/home/gberg/code/src/fstr/darwinpush/xsd/rttiCTTReferenceSchema_v3.xsd', 244, 3)
    
    code = property(__code.value, __code.set, None, 'This is the 4 letter CIS code')

    
    # Attribute name uses Python identifier name
    __name = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, 'name'), 'name', '__httpwww_thalesgroup_comrttiXmlRefDatav3_CTD_ANON_7_name', CISSourceName, required=True)
    __name._DeclarationLocation = pyxb.utils.utility.Location('/home/gberg/code/src/fstr/darwinpush/xsd/rttiCTTReferenceSchema_v3.xsd', 249, 3)
    __name._UseLocation = pyxb.utils.utility.Location('/home/gberg/code/src/fstr/darwinpush/xsd/rttiCTTReferenceSchema_v3.xsd', 249, 3)
    
    name = property(__name.value, __name.set, None, 'The CIS name')

    _ElementMap.update({
        
    })
    _AttributeMap.update({
        __code.name() : __code,
        __name.name() : __name
    })



PportTimetableRef = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'PportTimetableRef'), CTD_ANON_2, documentation='Push Port Timetable Reference Schema ', location=pyxb.utils.utility.Location('/home/gberg/code/src/fstr/darwinpush/xsd/rttiCTTReferenceSchema_v3.xsd', 125, 1))
Namespace.addCategoryObject('elementBinding', PportTimetableRef.name().localName(), PportTimetableRef)

LocationRef = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'LocationRef'), CTD_ANON_3, documentation='Defines a location', location=pyxb.utils.utility.Location('/home/gberg/code/src/fstr/darwinpush/xsd/rttiCTTReferenceSchema_v3.xsd', 153, 1))
Namespace.addCategoryObject('elementBinding', LocationRef.name().localName(), LocationRef)

TocRef = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'TocRef'), CTD_ANON_4, documentation='Defines a mapping between a TOC and a displayable name', location=pyxb.utils.utility.Location('/home/gberg/code/src/fstr/darwinpush/xsd/rttiCTTReferenceSchema_v3.xsd', 180, 1))
Namespace.addCategoryObject('elementBinding', TocRef.name().localName(), TocRef)

Reason = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'Reason'), CTD_ANON_5, documentation='Defines a mapping bewteen a reason code and the corresponding text', location=pyxb.utils.utility.Location('/home/gberg/code/src/fstr/darwinpush/xsd/rttiCTTReferenceSchema_v3.xsd', 198, 1))
Namespace.addCategoryObject('elementBinding', Reason.name().localName(), Reason)

Via = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'Via'), CTD_ANON_6, documentation='Defines the locations a journey must be viewed from, go to and pass through for the corresponding via text to be displayed', location=pyxb.utils.utility.Location('/home/gberg/code/src/fstr/darwinpush/xsd/rttiCTTReferenceSchema_v3.xsd', 207, 1))
Namespace.addCategoryObject('elementBinding', Via.name().localName(), Via)

CISSource = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'CISSource'), CTD_ANON_7, documentation='Defines the mapping between 4 letter CIS codes and the CIS name', location=pyxb.utils.utility.Location('/home/gberg/code/src/fstr/darwinpush/xsd/rttiCTTReferenceSchema_v3.xsd', 239, 1))
Namespace.addCategoryObject('elementBinding', CISSource.name().localName(), CISSource)



CTD_ANON._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'Reason'), CTD_ANON_5, scope=CTD_ANON, documentation='Defines a mapping bewteen a reason code and the corresponding text', location=pyxb.utils.utility.Location('/home/gberg/code/src/fstr/darwinpush/xsd/rttiCTTReferenceSchema_v3.xsd', 198, 1)))

def _BuildAutomaton ():
    # Remove this helper function from the namespace after it is invoked
    global _BuildAutomaton
    del _BuildAutomaton
    import pyxb.utils.fac as fac

    counters = set()
    states = []
    final_update = set()
    symbol = pyxb.binding.content.ElementUse(CTD_ANON._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'Reason')), pyxb.utils.utility.Location('/home/gberg/code/src/fstr/darwinpush/xsd/rttiCTTReferenceSchema_v3.xsd', 136, 7))
    st_0 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_0)
    transitions = []
    transitions.append(fac.Transition(st_0, [
         ]))
    st_0._set_transitionSet(transitions)
    return fac.Automaton(states, counters, False, containing_state=None)
CTD_ANON._Automaton = _BuildAutomaton()




CTD_ANON_._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'Reason'), CTD_ANON_5, scope=CTD_ANON_, documentation='Defines a mapping bewteen a reason code and the corresponding text', location=pyxb.utils.utility.Location('/home/gberg/code/src/fstr/darwinpush/xsd/rttiCTTReferenceSchema_v3.xsd', 198, 1)))

def _BuildAutomaton_ ():
    # Remove this helper function from the namespace after it is invoked
    global _BuildAutomaton_
    del _BuildAutomaton_
    import pyxb.utils.fac as fac

    counters = set()
    states = []
    final_update = set()
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'Reason')), pyxb.utils.utility.Location('/home/gberg/code/src/fstr/darwinpush/xsd/rttiCTTReferenceSchema_v3.xsd', 143, 7))
    st_0 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_0)
    transitions = []
    transitions.append(fac.Transition(st_0, [
         ]))
    st_0._set_transitionSet(transitions)
    return fac.Automaton(states, counters, False, containing_state=None)
CTD_ANON_._Automaton = _BuildAutomaton_()




CTD_ANON_2._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'LateRunningReasons'), CTD_ANON, scope=CTD_ANON_2, location=pyxb.utils.utility.Location('/home/gberg/code/src/fstr/darwinpush/xsd/rttiCTTReferenceSchema_v3.xsd', 133, 4)))

CTD_ANON_2._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'CancellationReasons'), CTD_ANON_, scope=CTD_ANON_2, location=pyxb.utils.utility.Location('/home/gberg/code/src/fstr/darwinpush/xsd/rttiCTTReferenceSchema_v3.xsd', 140, 4)))

CTD_ANON_2._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'LocationRef'), CTD_ANON_3, scope=CTD_ANON_2, documentation='Defines a location', location=pyxb.utils.utility.Location('/home/gberg/code/src/fstr/darwinpush/xsd/rttiCTTReferenceSchema_v3.xsd', 153, 1)))

CTD_ANON_2._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'TocRef'), CTD_ANON_4, scope=CTD_ANON_2, documentation='Defines a mapping between a TOC and a displayable name', location=pyxb.utils.utility.Location('/home/gberg/code/src/fstr/darwinpush/xsd/rttiCTTReferenceSchema_v3.xsd', 180, 1)))

CTD_ANON_2._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'Via'), CTD_ANON_6, scope=CTD_ANON_2, documentation='Defines the locations a journey must be viewed from, go to and pass through for the corresponding via text to be displayed', location=pyxb.utils.utility.Location('/home/gberg/code/src/fstr/darwinpush/xsd/rttiCTTReferenceSchema_v3.xsd', 207, 1)))

CTD_ANON_2._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'CISSource'), CTD_ANON_7, scope=CTD_ANON_2, documentation='Defines the mapping between 4 letter CIS codes and the CIS name', location=pyxb.utils.utility.Location('/home/gberg/code/src/fstr/darwinpush/xsd/rttiCTTReferenceSchema_v3.xsd', 239, 1)))

def _BuildAutomaton_2 ():
    # Remove this helper function from the namespace after it is invoked
    global _BuildAutomaton_2
    del _BuildAutomaton_2
    import pyxb.utils.fac as fac

    counters = set()
    cc_0 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('/home/gberg/code/src/fstr/darwinpush/xsd/rttiCTTReferenceSchema_v3.xsd', 131, 4))
    counters.add(cc_0)
    cc_1 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('/home/gberg/code/src/fstr/darwinpush/xsd/rttiCTTReferenceSchema_v3.xsd', 132, 4))
    counters.add(cc_1)
    cc_2 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('/home/gberg/code/src/fstr/darwinpush/xsd/rttiCTTReferenceSchema_v3.xsd', 133, 4))
    counters.add(cc_2)
    cc_3 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('/home/gberg/code/src/fstr/darwinpush/xsd/rttiCTTReferenceSchema_v3.xsd', 140, 4))
    counters.add(cc_3)
    cc_4 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('/home/gberg/code/src/fstr/darwinpush/xsd/rttiCTTReferenceSchema_v3.xsd', 147, 4))
    counters.add(cc_4)
    cc_5 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('/home/gberg/code/src/fstr/darwinpush/xsd/rttiCTTReferenceSchema_v3.xsd', 148, 4))
    counters.add(cc_5)
    states = []
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_0, False))
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_2._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'LocationRef')), pyxb.utils.utility.Location('/home/gberg/code/src/fstr/darwinpush/xsd/rttiCTTReferenceSchema_v3.xsd', 131, 4))
    st_0 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_0)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_1, False))
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_2._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'TocRef')), pyxb.utils.utility.Location('/home/gberg/code/src/fstr/darwinpush/xsd/rttiCTTReferenceSchema_v3.xsd', 132, 4))
    st_1 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_1)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_2, False))
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_2._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'LateRunningReasons')), pyxb.utils.utility.Location('/home/gberg/code/src/fstr/darwinpush/xsd/rttiCTTReferenceSchema_v3.xsd', 133, 4))
    st_2 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_2)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_3, False))
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_2._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'CancellationReasons')), pyxb.utils.utility.Location('/home/gberg/code/src/fstr/darwinpush/xsd/rttiCTTReferenceSchema_v3.xsd', 140, 4))
    st_3 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_3)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_4, False))
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_2._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'Via')), pyxb.utils.utility.Location('/home/gberg/code/src/fstr/darwinpush/xsd/rttiCTTReferenceSchema_v3.xsd', 147, 4))
    st_4 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_4)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_5, False))
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_2._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'CISSource')), pyxb.utils.utility.Location('/home/gberg/code/src/fstr/darwinpush/xsd/rttiCTTReferenceSchema_v3.xsd', 148, 4))
    st_5 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_5)
    transitions = []
    transitions.append(fac.Transition(st_0, [
        fac.UpdateInstruction(cc_0, True) ]))
    transitions.append(fac.Transition(st_1, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_0, False) ]))
    st_0._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_1, [
        fac.UpdateInstruction(cc_1, True) ]))
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_1, False) ]))
    st_1._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_2, True) ]))
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_2, False) ]))
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_2, False) ]))
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_2, False) ]))
    st_2._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_3, True) ]))
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_3, False) ]))
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_3, False) ]))
    st_3._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_4, True) ]))
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_4, False) ]))
    st_4._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_5, True) ]))
    st_5._set_transitionSet(transitions)
    return fac.Automaton(states, counters, True, containing_state=None)
CTD_ANON_2._Automaton = _BuildAutomaton_2()




# ./darwinpush/xb/raw/td.py
# -*- coding: utf-8 -*-
# PyXB bindings for NM:ec3ff59c2418d971c0c03ea43d7e8b23a3496599
# Generated 2015-04-23 16:42:14.517941 by PyXB version 1.2.4 using Python 3.4.1.final.0
# Namespace http://www.thalesgroup.com/rtti/PushPort/TDData/v1 [xmlns:td]

from __future__ import unicode_literals
import pyxb
import pyxb.binding
import pyxb.binding.saxer
import io
import pyxb.utils.utility
import pyxb.utils.domutils
import sys
import pyxb.utils.six as _six

# Unique identifier for bindings created at the same time
_GenerationUID = pyxb.utils.utility.UniqueIdentifier('urn:uuid:5049f1de-e9cf-11e4-bb50-a0481ca50ab0')

# Version of PyXB used to generate the bindings
_PyXBVersion = '1.2.4'
# Generated bindings are not compatible across PyXB versions
if pyxb.__version__ != _PyXBVersion:
    raise pyxb.PyXBVersionError(_PyXBVersion)

# Import bindings for namespaces imported into schema
import pyxb.binding.datatypes
import darwinpush.xb.ct as _ImportedBinding_darwinpush_xb_ct

# NOTE: All namespace declarations are reserved within the binding
Namespace = pyxb.namespace.NamespaceForURI('http://www.thalesgroup.com/rtti/PushPort/TDData/v1', create_if_missing=True)
Namespace.configureCategories(['typeBinding', 'elementBinding'])

def CreateFromDocument (xml_text, default_namespace=None, location_base=None):
    """Parse the given XML and use the document element to create a
    Python instance.

    @param xml_text An XML document.  This should be data (Python 2
    str or Python 3 bytes), or a text (Python 2 unicode or Python 3
    str) in the L{pyxb._InputEncoding} encoding.

    @keyword default_namespace The L{pyxb.Namespace} instance to use as the
    default namespace where there is no default namespace in scope.
    If unspecified or C{None}, the namespace of the module containing
    this function will be used.

    @keyword location_base: An object to be recorded as the base of all
    L{pyxb.utils.utility.Location} instances associated with events and
    objects handled by the parser.  You might pass the URI from which
    the document was obtained.
    """

    if pyxb.XMLStyle_saxer != pyxb._XMLStyle:
        dom = pyxb.utils.domutils.StringToDOM(xml_text)
        return CreateFromDOM(dom.documentElement, default_namespace=default_namespace)
    if default_namespace is None:
        default_namespace = Namespace.fallbackNamespace()
    saxer = pyxb.binding.saxer.make_parser(fallback_namespace=default_namespace, location_base=location_base)
    handler = saxer.getContentHandler()
    xmld = xml_text
    if isinstance(xmld, _six.text_type):
        xmld = xmld.encode(pyxb._InputEncoding)
    saxer.parse(io.BytesIO(xmld))
    instance = handler.rootObject()
    return instance

def CreateFromDOM (node, default_namespace=None):
    """Create a Python instance from the given DOM node.
    The node tag must correspond to an element declaration in this module.

    @deprecated: Forcing use of DOM interface is unnecessary; use L{CreateFromDocument}."""
    if default_namespace is None:
        default_namespace = Namespace.fallbackNamespace()
    return pyxb.binding.basis.element.AnyCreateFromDOM(node, default_namespace)


# Complex type {http://www.thalesgroup.com/rtti/PushPort/TDData/v1}TrackingID with content type ELEMENT_ONLY
class TrackingID (pyxb.binding.basis.complexTypeDefinition):
    """Indicate a corrected Tracking ID (headcode) for a service in a TD berth."""
    _TypeDefinition = None
    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_ELEMENT_ONLY
    _Abstract = False
    _ExpandedName = pyxb.namespace.ExpandedName(Namespace, 'TrackingID')
    _XSDLocation = pyxb.utils.utility.Location('/home/gberg/code/src/fstr/darwinpush/xsd/rttiPPTTDData_v1.xsd', 23, 1)
    _ElementMap = {}
    _AttributeMap = {}
    # Base type is pyxb.binding.datatypes.anyType
    
    # Element {http://www.thalesgroup.com/rtti/PushPort/TDData/v1}berth uses Python identifier berth
    __berth = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'berth'), 'berth', '__httpwww_thalesgroup_comrttiPushPortTDDatav1_TrackingID_httpwww_thalesgroup_comrttiPushPortTDDatav1berth', False, pyxb.utils.utility.Location('/home/gberg/code/src/fstr/darwinpush/xsd/rttiPPTTDData_v1.xsd', 28, 3), )

    
    berth = property(__berth.value, __berth.set, None, 'The TD berth where the incorrectly reported train has been identified to be. Note that this berth is that which was reported to Darwin and there is no guarantee that the train is still in this berth at any subsequent point in time.')

    
    # Element {http://www.thalesgroup.com/rtti/PushPort/TDData/v1}incorrectTrainID uses Python identifier incorrectTrainID
    __incorrectTrainID = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'incorrectTrainID'), 'incorrectTrainID', '__httpwww_thalesgroup_comrttiPushPortTDDatav1_TrackingID_httpwww_thalesgroup_comrttiPushPortTDDatav1incorrectTrainID', False, pyxb.utils.utility.Location('/home/gberg/code/src/fstr/darwinpush/xsd/rttiPPTTDData_v1.xsd', 33, 3), )

    
    incorrectTrainID = property(__incorrectTrainID.value, __incorrectTrainID.set, None, 'The incorrect Train ID (headcode) that is being reported by TD.NET.')

    
    # Element {http://www.thalesgroup.com/rtti/PushPort/TDData/v1}correctTrainID uses Python identifier correctTrainID
    __correctTrainID = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'correctTrainID'), 'correctTrainID', '__httpwww_thalesgroup_comrttiPushPortTDDatav1_TrackingID_httpwww_thalesgroup_comrttiPushPortTDDatav1correctTrainID', False, pyxb.utils.utility.Location('/home/gberg/code/src/fstr/darwinpush/xsd/rttiPPTTDData_v1.xsd', 38, 3), )

    
    correctTrainID = property(__correctTrainID.value, __correctTrainID.set, None, 'The correct Train ID (headcode) that should be reported by TD.NET.')

    _ElementMap.update({
        __berth.name() : __berth,
        __incorrectTrainID.name() : __incorrectTrainID,
        __correctTrainID.name() : __correctTrainID
    })
    _AttributeMap.update({
        
    })
Namespace.addCategoryObject('typeBinding', 'TrackingID', TrackingID)


# Complex type {http://www.thalesgroup.com/rtti/PushPort/TDData/v1}FullTDBerthID with content type SIMPLE
class FullTDBerthID (pyxb.binding.basis.complexTypeDefinition):
    """Complex type {http://www.thalesgroup.com/rtti/PushPort/TDData/v1}FullTDBerthID with content type SIMPLE"""
    _TypeDefinition = _ImportedBinding_darwinpush_xb_ct.TDBerthIDType
    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_SIMPLE
    _Abstract = False
    _ExpandedName = pyxb.namespace.ExpandedName(Namespace, 'FullTDBerthID')
    _XSDLocation = pyxb.utils.utility.Location('/home/gberg/code/src/fstr/darwinpush/xsd/rttiPPTTDData_v1.xsd', 16, 1)
    _ElementMap = {}
    _AttributeMap = {}
    # Base type is _ImportedBinding_darwinpush_xb_ct.TDBerthIDType
    
    # Attribute area uses Python identifier area
    __area = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, 'area'), 'area', '__httpwww_thalesgroup_comrttiPushPortTDDatav1_FullTDBerthID_area', _ImportedBinding_darwinpush_xb_ct.TDAreaIDType, required=True)
    __area._DeclarationLocation = pyxb.utils.utility.Location('/home/gberg/code/src/fstr/darwinpush/xsd/rttiPPTTDData_v1.xsd', 19, 4)
    __area._UseLocation = pyxb.utils.utility.Location('/home/gberg/code/src/fstr/darwinpush/xsd/rttiPPTTDData_v1.xsd', 19, 4)
    
    area = property(__area.value, __area.set, None, None)

    _ElementMap.update({
        
    })
    _AttributeMap.update({
        __area.name() : __area
    })
Namespace.addCategoryObject('typeBinding', 'FullTDBerthID', FullTDBerthID)




TrackingID._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'berth'), FullTDBerthID, scope=TrackingID, documentation='The TD berth where the incorrectly reported train has been identified to be. Note that this berth is that which was reported to Darwin and there is no guarantee that the train is still in this berth at any subsequent point in time.', location=pyxb.utils.utility.Location('/home/gberg/code/src/fstr/darwinpush/xsd/rttiPPTTDData_v1.xsd', 28, 3)))

TrackingID._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'incorrectTrainID'), _ImportedBinding_darwinpush_xb_ct.TrainIdType, scope=TrackingID, documentation='The incorrect Train ID (headcode) that is being reported by TD.NET.', location=pyxb.utils.utility.Location('/home/gberg/code/src/fstr/darwinpush/xsd/rttiPPTTDData_v1.xsd', 33, 3)))

TrackingID._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'correctTrainID'), _ImportedBinding_darwinpush_xb_ct.TrainIdType, scope=TrackingID, documentation='The correct Train ID (headcode) that should be reported by TD.NET.', location=pyxb.utils.utility.Location('/home/gberg/code/src/fstr/darwinpush/xsd/rttiPPTTDData_v1.xsd', 38, 3)))

def _BuildAutomaton ():
    # Remove this helper function from the namespace after it is invoked
    global _BuildAutomaton
    del _BuildAutomaton
    import pyxb.utils.fac as fac

    counters = set()
    states = []
    final_update = None
    symbol = pyxb.binding.content.ElementUse(TrackingID._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'berth')), pyxb.utils.utility.Location('/home/gberg/code/src/fstr/darwinpush/xsd/rttiPPTTDData_v1.xsd', 28, 3))
    st_0 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_0)
    final_update = None
    symbol = pyxb.binding.content.ElementUse(TrackingID._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'incorrectTrainID')), pyxb.utils.utility.Location('/home/gberg/code/src/fstr/darwinpush/xsd/rttiPPTTDData_v1.xsd', 33, 3))
    st_1 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_1)
    final_update = set()
    symbol = pyxb.binding.content.ElementUse(TrackingID._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'correctTrainID')), pyxb.utils.utility.Location('/home/gberg/code/src/fstr/darwinpush/xsd/rttiPPTTDData_v1.xsd', 38, 3))
    st_2 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_2)
    transitions = []
    transitions.append(fac.Transition(st_1, [
         ]))
    st_0._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_2, [
         ]))
    st_1._set_transitionSet(transitions)
    transitions = []
    st_2._set_transitionSet(transitions)
    return fac.Automaton(states, counters, False, containing_state=None)
TrackingID._Automaton = _BuildAutomaton()

